# encoding: UTF-8

module ChineseDetector
  private

  def traditional_chinese_regex
    /#{traditional_chinese_characters.join('|')}/
  end

  def simplified_chinese_regex
    /#{simplified_chinese_characters.join('|')}/
  end

  def traditional_chinese_characters
    [ '\u346F',
    '\u3473',
    '\u3493',
    '\u34E8',
    '\u35F2',
    '\u361A',
    '\u3704',
    '\u370F',
    '\u3722',
    '\u3737',
    '\u379E',
    '\u380F',
    '\u389D',
    '\u396E',
    '\u398E',
    '\u3A5C',
    '\u3A73',
    '\u3DFF',
    '\u3E8F',
    '\u3FE7',
    '\u4039',
    '\u406A',
    '\u407B',
    '\u4259',
    '\u426C',
    '\u4272',
    '\u42AD',
    '\u42B7',
    '\u42D9',
    '\u42DA',
    '\u42FB',
    '\u42FF',
    '\u4308',
    '\u430B',
    '\u4316',
    '\u431D',
    '\u431F',
    '\u4325',
    '\u4330',
    '\u4573',
    '\u45FF',
    '\u4661',
    '\u4700',
    '\u477B',
    '\u477C',
    '\u4788',
    '\u48A8',
    '\u4947',
    '\u4969',
    '\u4971',
    '\u4998',
    '\u499B',
    '\u499F',
    '\u49B3',
    '\u49E2',
    '\u4A8F',
    '\u4A97',
    '\u4A98',
    '\u4AF4',
    '\u4B18',
    '\u4B1D',
    '\u4B1E',
    '\u4B40',
    '\u4B43',
    '\u4B7F',
    '\u4B9D',
    '\u4B9E',
    '\u4BA0',
    '\u4BAB',
    '\u4BB3',
    '\u4BBE',
    '\u4BC0',
    '\u4C3E',
    '\u4C59',
    '\u4C6C',
    '\u4C70',
    '\u4C77',
    '\u4C7D',
    '\u4C81',
    '\u4C96',
    '\u4CB0',
    '\u4D09',
    '\u4D2C',
    '\u4D34',
    '\u4E1F',
    '\u4E26',
    '\u4E7E',
    '\u4E82',
    '\u4E9E',
    '\u4F47',
    '\u4F59',
    '\u4F75',
    '\u4F86',
    '\u4F96',
    '\u4FB6',
    '\u4FC1',
    '\u4FC2',
    '\u4FD4',
    '\u4FE0',
    '\u4FE5',
    '\u5000',
    '\u5006',
    '\u5008',
    '\u5009',
    '\u500B',
    '\u5011',
    '\u502B',
    '\u5032',
    '\u5049',
    '\u5051',
    '\u5074',
    '\u5075',
    '\u507D',
    '\u5091',
    '\u5096',
    '\u5098',
    '\u5099',
    '\u50AD',
    '\u50AF',
    '\u50B3',
    '\u50B4',
    '\u50B5',
    '\u50B7',
    '\u50BE',
    '\u50C2',
    '\u50C5',
    '\u50C9',
    '\u50D1',
    '\u50D5',
    '\u50DE',
    '\u50E5',
    '\u50E8',
    '\u50F9',
    '\u5100',
    '\u5102',
    '\u5104',
    '\u5108',
    '\u5109',
    '\u5110',
    '\u5114',
    '\u5115',
    '\u5118',
    '\u511F',
    '\u5123',
    '\u512A',
    '\u5132',
    '\u5137',
    '\u5138',
    '\u513A',
    '\u513B',
    '\u513C',
    '\u514C',
    '\u5152',
    '\u5157',
    '\u5167',
    '\u5169',
    '\u518A',
    '\u51AA',
    '\u51C8',
    '\u51CD',
    '\u51D9',
    '\u51DC',
    '\u51F1',
    '\u5225',
    '\u522A',
    '\u5244',
    '\u5247',
    '\u524B',
    '\u524E',
    '\u5257',
    '\u525B',
    '\u525D',
    '\u526E',
    '\u5274',
    '\u5275',
    '\u527E',
    '\u5283',
    '\u5287',
    '\u5289',
    '\u528A',
    '\u528C',
    '\u528D',
    '\u528F',
    '\u5291',
    '\u529A',
    '\u52C1',
    '\u52D5',
    '\u52D9',
    '\u52DB',
    '\u52DD',
    '\u52DE',
    '\u52E2',
    '\u52E9',
    '\u52F1',
    '\u52F5',
    '\u52F8',
    '\u52FB',
    '\u532D',
    '\u532F',
    '\u5331',
    '\u5340',
    '\u5354',
    '\u537B',
    '\u5399',
    '\u53AD',
    '\u53B2',
    '\u53B4',
    '\u53C3',
    '\u53C4',
    '\u53E2',
    '\u53F0',
    '\u540E',
    '\u5412',
    '\u5433',
    '\u5436',
    '\u5442',
    '\u54BC',
    '\u54E1',
    '\u54EF',
    '\u5504',
    '\u551A',
    '\u554F',
    '\u555E',
    '\u555F',
    '\u5562',
    '\u558E',
    '\u559A',
    '\u55AA',
    '\u55AC',
    '\u55AE',
    '\u55B2',
    '\u55C6',
    '\u55C7',
    '\u55CA',
    '\u55CE',
    '\u55DA',
    '\u55E9',
    '\u55F6',
    '\u55F9',
    '\u5606',
    '\u560D',
    '\u5613',
    '\u5614',
    '\u5616',
    '\u5617',
    '\u561C',
    '\u5629',
    '\u562E',
    '\u562F',
    '\u5630',
    '\u5635',
    '\u5638',
    '\u563D',
    '\u5645',
    '\u5653',
    '\u565A',
    '\u565D',
    '\u5660',
    '\u5665',
    '\u5666',
    '\u566F',
    '\u5672',
    '\u5674',
    '\u5678',
    '\u5679',
    '\u5680',
    '\u5687',
    '\u568C',
    '\u5695',
    '\u5699',
    '\u56A6',
    '\u56A8',
    '\u56B2',
    '\u56B3',
    '\u56B4',
    '\u56B6',
    '\u56C0',
    '\u56C1',
    '\u56C2',
    '\u56C5',
    '\u56C8',
    '\u56C9',
    '\u56D1',
    '\u56EA',
    '\u5707',
    '\u570B',
    '\u570D',
    '\u5712',
    '\u5713',
    '\u5716',
    '\u5718',
    '\u571E',
    '\u57B5',
    '\u57E1',
    '\u57F0',
    '\u57F7',
    '\u5805',
    '\u580A',
    '\u5816',
    '\u581D',
    '\u582F',
    '\u5831',
    '\u5834',
    '\u584A',
    '\u584B',
    '\u584F',
    '\u5852',
    '\u5857',
    '\u5862',
    '\u5864',
    '\u5875',
    '\u5879',
    '\u588A',
    '\u589C',
    '\u58AE',
    '\u58B3',
    '\u58BE',
    '\u58C7',
    '\u58C8',
    '\u58CB',
    '\u58D3',
    '\u58D8',
    '\u58D9',
    '\u58DA',
    '\u58DE',
    '\u58DF',
    '\u58E0',
    '\u58E2',
    '\u58E9',
    '\u58EF',
    '\u58FA',
    '\u58FC',
    '\u58FD',
    '\u5920',
    '\u5922',
    '\u593E',
    '\u5950',
    '\u5967',
    '\u5969',
    '\u596A',
    '\u596E',
    '\u597C',
    '\u599D',
    '\u59CD',
    '\u59E6',
    '\u5A1B',
    '\u5A41',
    '\u5A66',
    '\u5A6D',
    '\u5AA7',
    '\u5AAF',
    '\u5AB0',
    '\u5ABC',
    '\u5ABD',
    '\u5AD7',
    '\u5AF5',
    '\u5AFB',
    '\u5AFF',
    '\u5B08',
    '\u5B0B',
    '\u5B0C',
    '\u5B19',
    '\u5B21',
    '\u5B24',
    '\u5B2A',
    '\u5B30',
    '\u5B38',
    '\u5B4B',
    '\u5B4C',
    '\u5B6B',
    '\u5B78',
    '\u5B7F',
    '\u5BAE',
    '\u5BE2',
    '\u5BE6',
    '\u5BE7',
    '\u5BE9',
    '\u5BEB',
    '\u5BEC',
    '\u5BF5',
    '\u5BF6',
    '\u5C07',
    '\u5C08',
    '\u5C0B',
    '\u5C0D',
    '\u5C0E',
    '\u5C37',
    '\u5C46',
    '\u5C4D',
    '\u5C53',
    '\u5C5C',
    '\u5C62',
    '\u5C64',
    '\u5C68',
    '\u5C69',
    '\u5C6C',
    '\u5CA1',
    '\u5CF4',
    '\u5CF6',
    '\u5CFD',
    '\u5D0D',
    '\u5D17',
    '\u5D22',
    '\u5D2C',
    '\u5D50',
    '\u5D7C',
    '\u5D81',
    '\u5D84',
    '\u5D87',
    '\u5D94',
    '\u5D97',
    '\u5DA0',
    '\u5DA2',
    '\u5DA7',
    '\u5DAE',
    '\u5DB4',
    '\u5DB8',
    '\u5DBA',
    '\u5DBC',
    '\u5DCB',
    '\u5DD2',
    '\u5DD4',
    '\u5DF0',
    '\u5E25',
    '\u5E2B',
    '\u5E33',
    '\u5E36',
    '\u5E40',
    '\u5E43',
    '\u5E57',
    '\u5E58',
    '\u5E5F',
    '\u5E63',
    '\u5E6B',
    '\u5E6C',
    '\u5E79',
    '\u5E7A',
    '\u5E7E',
    '\u5EAB',
    '\u5EC1',
    '\u5EC2',
    '\u5EC4',
    '\u5EC8',
    '\u5EDA',
    '\u5EDD',
    '\u5EDF',
    '\u5EE0',
    '\u5EE1',
    '\u5EE2',
    '\u5EE3',
    '\u5EE9',
    '\u5EEC',
    '\u5EF3',
    '\u5F12',
    '\u5F33',
    '\u5F35',
    '\u5F37',
    '\u5F48',
    '\u5F4C',
    '\u5F4E',
    '\u5F59',
    '\u5F5E',
    '\u5F65',
    '\u5F72',
    '\u5F8C',
    '\u5F91',
    '\u5F9E',
    '\u5FA0',
    '\u5FA9',
    '\u5FB5',
    '\u5FB9',
    '\u5FD7',
    '\u6046',
    '\u6065',
    '\u6085',
    '\u609E',
    '\u60B5',
    '\u60B6',
    '\u60E1',
    '\u60F1',
    '\u60F2',
    '\u60FB',
    '\u611B',
    '\u611C',
    '\u6128',
    '\u6134',
    '\u6137',
    '\u613E',
    '\u6144',
    '\u614B',
    '\u614D',
    '\u6158',
    '\u615A',
    '\u615F',
    '\u6163',
    '\u616A',
    '\u616B',
    '\u616E',
    '\u6173',
    '\u6176',
    '\u6182',
    '\u618A',
    '\u6190',
    '\u6191',
    '\u6192',
    '\u619A',
    '\u61A4',
    '\u61AB',
    '\u61AE',
    '\u61B2',
    '\u61B6',
    '\u61C0',
    '\u61C7',
    '\u61C9',
    '\u61CC',
    '\u61CD',
    '\u61DF',
    '\u61E3',
    '\u61E8',
    '\u61F2',
    '\u61F6',
    '\u61F7',
    '\u61F8',
    '\u61FA',
    '\u61FC',
    '\u61FE',
    '\u6200',
    '\u6207',
    '\u6214',
    '\u6227',
    '\u6229',
    '\u6230',
    '\u6231',
    '\u6232',
    '\u6236',
    '\u62CB',
    '\u6329',
    '\u633E',
    '\u6368',
    '\u636B',
    '\u6383',
    '\u6384',
    '\u6386',
    '\u6397',
    '\u6399',
    '\u639B',
    '\u63A1',
    '\u63C0',
    '\u63DA',
    '\u63DB',
    '\u63EE',
    '\u640D',
    '\u6416',
    '\u6417',
    '\u6435',
    '\u6436',
    '\u644B',
    '\u6451',
    '\u645C',
    '\u645F',
    '\u646F',
    '\u6473',
    '\u6476',
    '\u647B',
    '\u6488',
    '\u648F',
    '\u6490',
    '\u6493',
    '\u649D',
    '\u649F',
    '\u64A3',
    '\u64A5',
    '\u64AB',
    '\u64B2',
    '\u64B3',
    '\u64BB',
    '\u64BE',
    '\u64BF',
    '\u64C1',
    '\u64C4',
    '\u64C7',
    '\u64CA',
    '\u64CB',
    '\u64D3',
    '\u64D4',
    '\u64DA',
    '\u64E0',
    '\u64E3',
    '\u64EC',
    '\u64EF',
    '\u64F0',
    '\u64F1',
    '\u64F2',
    '\u64F4',
    '\u64F7',
    '\u64FA',
    '\u64FB',
    '\u64FC',
    '\u64FD',
    '\u64FE',
    '\u6504',
    '\u6506',
    '\u650F',
    '\u6514',
    '\u6516',
    '\u6519',
    '\u651B',
    '\u651C',
    '\u651D',
    '\u6522',
    '\u6523',
    '\u6524',
    '\u652A',
    '\u652C',
    '\u6557',
    '\u6558',
    '\u6575',
    '\u6578',
    '\u6582',
    '\u6583',
    '\u6585',
    '\u6586',
    '\u6595',
    '\u65AC',
    '\u65B7',
    '\u65BC',
    '\u6642',
    '\u6649',
    '\u665D',
    '\u6688',
    '\u6689',
    '\u6698',
    '\u66A2',
    '\u66AB',
    '\u66C4',
    '\u66C6',
    '\u66C7',
    '\u66C9',
    '\u66CF',
    '\u66D6',
    '\u66E0',
    '\u66E5',
    '\u66E8',
    '\u66EC',
    '\u66F8',
    '\u6703',
    '\u6725',
    '\u6727',
    '\u6771',
    '\u6774',
    '\u6781',
    '\u67F5',
    '\u687F',
    '\u6894',
    '\u6898',
    '\u689D',
    '\u689F',
    '\u68B2',
    '\u68C4',
    '\u68D6',
    '\u68D7',
    '\u68DF',
    '\u68E1',
    '\u68E7',
    '\u68F2',
    '\u68F6',
    '\u690F',
    '\u6932',
    '\u694A',
    '\u6953',
    '\u6968',
    '\u696D',
    '\u6975',
    '\u69AA',
    '\u69AE',
    '\u69B2',
    '\u69BF',
    '\u69CB',
    '\u69CD',
    '\u69E4',
    '\u69E7',
    '\u69E8',
    '\u69F3',
    '\u69F6',
    '\u6A01',
    '\u6A02',
    '\u6A05',
    '\u6A13',
    '\u6A19',
    '\u6A1E',
    '\u6A22',
    '\u6A23',
    '\u6A2B',
    '\u6A38',
    '\u6A39',
    '\u6A3A',
    '\u6A3F',
    '\u6A48',
    '\u6A4B',
    '\u6A5F',
    '\u6A62',
    '\u6A6B',
    '\u6A81',
    '\u6A89',
    '\u6A94',
    '\u6A9C',
    '\u6A9F',
    '\u6AA2',
    '\u6AA3',
    '\u6AAD',
    '\u6AAE',
    '\u6AAF',
    '\u6AB3',
    '\u6AB8',
    '\u6ABB',
    '\u6AC3',
    '\u6AD3',
    '\u6ADA',
    '\u6ADB',
    '\u6ADD',
    '\u6ADE',
    '\u6ADF',
    '\u6AE5',
    '\u6AE7',
    '\u6AE8',
    '\u6AEA',
    '\u6AEB',
    '\u6AEC',
    '\u6AF1',
    '\u6AF3',
    '\u6AF8',
    '\u6AFB',
    '\u6B04',
    '\u6B0A',
    '\u6B0D',
    '\u6B0F',
    '\u6B12',
    '\u6B13',
    '\u6B16',
    '\u6B1E',
    '\u6B3D',
    '\u6B50',
    '\u6B5F',
    '\u6B61',
    '\u6B72',
    '\u6B77',
    '\u6B78',
    '\u6B7F',
    '\u6B98',
    '\u6B9E',
    '\u6BA4',
    '\u6BA8',
    '\u6BAB',
    '\u6BAE',
    '\u6BAF',
    '\u6BB0',
    '\u6BB2',
    '\u6BBA',
    '\u6BBC',
    '\u6BC0',
    '\u6BC6',
    '\u6BFF',
    '\u6C02',
    '\u6C08',
    '\u6C0C',
    '\u6C23',
    '\u6C2B',
    '\u6C2C',
    '\u6C33',
    '\u6C7A',
    '\u6C92',
    '\u6C96',
    '\u6CC1',
    '\u6D36',
    '\u6D79',
    '\u6D87',
    '\u6DBC',
    '\u6DDA',
    '\u6DE5',
    '\u6DEA',
    '\u6DF5',
    '\u6DF6',
    '\u6DFA',
    '\u6E19',
    '\u6E1B',
    '\u6E22',
    '\u6E26',
    '\u6E2C',
    '\u6E3E',
    '\u6E4A',
    '\u6E5E',
    '\u6E6F',
    '\u6E88',
    '\u6E96',
    '\u6E9D',
    '\u6EAB',
    '\u6EB3',
    '\u6EC4',
    '\u6EC5',
    '\u6ECC',
    '\u6ECE',
    '\u6EEC',
    '\u6EEF',
    '\u6EF2',
    '\u6EF8',
    '\u6EFB',
    '\u6EFE',
    '\u6EFF',
    '\u6F01',
    '\u6F0A',
    '\u6F1A',
    '\u6F22',
    '\u6F23',
    '\u6F2C',
    '\u6F32',
    '\u6F35',
    '\u6F38',
    '\u6F3F',
    '\u6F41',
    '\u6F51',
    '\u6F54',
    '\u6F5B',
    '\u6F64',
    '\u6F6F',
    '\u6F70',
    '\u6F77',
    '\u6F7F',
    '\u6F80',
    '\u6F85',
    '\u6F86',
    '\u6F87',
    '\u6F97',
    '\u6FA0',
    '\u6FA4',
    '\u6FA6',
    '\u6FA9',
    '\u6FAE',
    '\u6FB1',
    '\u6FBE',
    '\u6FC1',
    '\u6FC3',
    '\u6FC4',
    '\u6FC6',
    '\u6FD5',
    '\u6FD8',
    '\u6FDC',
    '\u6FDF',
    '\u6FE4',
    '\u6FE7',
    '\u6FEB',
    '\u6FF0',
    '\u6FF1',
    '\u6FFA',
    '\u6FFC',
    '\u6FFE',
    '\u7002',
    '\u7003',
    '\u7005',
    '\u7006',
    '\u7007',
    '\u7009',
    '\u700B',
    '\u700F',
    '\u7015',
    '\u7018',
    '\u701D',
    '\u701F',
    '\u7020',
    '\u7026',
    '\u7027',
    '\u7028',
    '\u7030',
    '\u7032',
    '\u703E',
    '\u7043',
    '\u7044',
    '\u7051',
    '\u7055',
    '\u7058',
    '\u7059',
    '\u705D',
    '\u7060',
    '\u7061',
    '\u7063',
    '\u7064',
    '\u7067',
    '\u707D',
    '\u70BA',
    '\u70CF',
    '\u70F4',
    '\u7121',
    '\u7149',
    '\u7152',
    '\u7159',
    '\u7162',
    '\u7165',
    '\u7169',
    '\u716C',
    '\u7171',
    '\u7185',
    '\u7189',
    '\u718C',
    '\u7192',
    '\u7193',
    '\u7197',
    '\u71A1',
    '\u71B1',
    '\u71B2',
    '\u71BE',
    '\u71C1',
    '\u71C8',
    '\u71D2',
    '\u71D9',
    '\u71DC',
    '\u71DF',
    '\u71E6',
    '\u71ED',
    '\u71F4',
    '\u71F6',
    '\u71FC',
    '\u71FE',
    '\u7204',
    '\u720D',
    '\u7210',
    '\u721B',
    '\u722D',
    '\u723A',
    '\u723E',
    '\u7246',
    '\u7258',
    '\u727D',
    '\u7296',
    '\u72A2',
    '\u72A7',
    '\u72C0',
    '\u72F9',
    '\u72FD',
    '\u7319',
    '\u7336',
    '\u733B',
    '\u7341',
    '\u7344',
    '\u7345',
    '\u734E',
    '\u7368',
    '\u736A',
    '\u736B',
    '\u736E',
    '\u7370',
    '\u7371',
    '\u7372',
    '\u7375',
    '\u7377',
    '\u7378',
    '\u737A',
    '\u737B',
    '\u737C',
    '\u7380',
    '\u7381',
    '\u73FE',
    '\u743A',
    '\u743F',
    '\u744B',
    '\u7452',
    '\u7463',
    '\u7464',
    '\u7469',
    '\u746A',
    '\u7472',
    '\u747D',
    '\u7489',
    '\u74A3',
    '\u74A6',
    '\u74AB',
    '\u74AF',
    '\u74B0',
    '\u74BD',
    '\u74CA',
    '\u74CF',
    '\u74D4',
    '\u74D5',
    '\u74DA',
    '\u750C',
    '\u7522',
    '\u755D',
    '\u7562',
    '\u756B',
    '\u7570',
    '\u7576',
    '\u7587',
    '\u758A',
    '\u75D9',
    '\u75FE',
    '\u7602',
    '\u760B',
    '\u760D',
    '\u7613',
    '\u761E',
    '\u7621',
    '\u7627',
    '\u762E',
    '\u7632',
    '\u763A',
    '\u7642',
    '\u7646',
    '\u7647',
    '\u7649',
    '\u7658',
    '\u765F',
    '\u7662',
    '\u7664',
    '\u7665',
    '\u7667',
    '\u7669',
    '\u766C',
    '\u766D',
    '\u766E',
    '\u7670',
    '\u7671',
    '\u7672',
    '\u767C',
    '\u769A',
    '\u769F',
    '\u76B0',
    '\u76B8',
    '\u76BA',
    '\u76DC',
    '\u76DE',
    '\u76E1',
    '\u76E3',
    '\u76E4',
    '\u76E7',
    '\u76EA',
    '\u7725',
    '\u773E',
    '\u774D',
    '\u774F',
    '\u775C',
    '\u775E',
    '\u7798',
    '\u779C',
    '\u779E',
    '\u77A4',
    '\u77B6',
    '\u77BC',
    '\u77D3',
    '\u77DA',
    '\u77EF',
    '\u785C',
    '\u7864',
    '\u7868',
    '\u786F',
    '\u7899',
    '\u78A9',
    '\u78AD',
    '\u78B8',
    '\u78BA',
    '\u78BC',
    '\u78BD',
    '\u78D1',
    '\u78DA',
    '\u78E0',
    '\u78E3',
    '\u78E7',
    '\u78EF',
    '\u78FD',
    '\u7904',
    '\u7906',
    '\u790E',
    '\u7912',
    '\u7919',
    '\u7926',
    '\u792A',
    '\u792B',
    '\u792C',
    '\u7931',
    '\u797F',
    '\u798D',
    '\u798E',
    '\u7995',
    '\u79A1',
    '\u79A6',
    '\u79AA',
    '\u79AE',
    '\u79B0',
    '\u79B1',
    '\u79BF',
    '\u79C8',
    '\u7A05',
    '\u7A08',
    '\u7A0F',
    '\u7A1F',
    '\u7A2E',
    '\u7A31',
    '\u7A40',
    '\u7A4C',
    '\u7A4D',
    '\u7A4E',
    '\u7A60',
    '\u7A61',
    '\u7A62',
    '\u7A69',
    '\u7A6B',
    '\u7A6D',
    '\u7AA9',
    '\u7AAA',
    '\u7AAE',
    '\u7AAF',
    '\u7AB5',
    '\u7AB6',
    '\u7ABA',
    '\u7AC4',
    '\u7AC5',
    '\u7AC7',
    '\u7ACA',
    '\u7AF6',
    '\u7B46',
    '\u7B4D',
    '\u7B67',
    '\u7B74',
    '\u7B8B',
    '\u7B8F',
    '\u7BC0',
    '\u7BC4',
    '\u7BC9',
    '\u7BCB',
    '\u7BD4',
    '\u7BD8',
    '\u7BE4',
    '\u7BE9',
    '\u7BF3',
    '\u7C00',
    '\u7C0D',
    '\u7C1E',
    '\u7C21',
    '\u7C23',
    '\u7C2B',
    '\u7C39',
    '\u7C3D',
    '\u7C3E',
    '\u7C43',
    '\u7C4B',
    '\u7C4C',
    '\u7C54',
    '\u7C59',
    '\u7C5B',
    '\u7C5C',
    '\u7C5F',
    '\u7C60',
    '\u7C69',
    '\u7C6A',
    '\u7C6C',
    '\u7C6E',
    '\u7CB5',
    '\u7CDD',
    '\u7CDE',
    '\u7CE7',
    '\u7CF2',
    '\u7CF4',
    '\u7CF6',
    '\u7CF9',
    '\u7CFE',
    '\u7D00',
    '\u7D02',
    '\u7D04',
    '\u7D05',
    '\u7D06',
    '\u7D07',
    '\u7D08',
    '\u7D09',
    '\u7D0B',
    '\u7D0D',
    '\u7D10',
    '\u7D13',
    '\u7D14',
    '\u7D15',
    '\u7D16',
    '\u7D17',
    '\u7D18',
    '\u7D19',
    '\u7D1A',
    '\u7D1B',
    '\u7D1C',
    '\u7D1D',
    '\u7D21',
    '\u7D2C',
    '\u7D30',
    '\u7D31',
    '\u7D32',
    '\u7D33',
    '\u7D35',
    '\u7D39',
    '\u7D3A',
    '\u7D3C',
    '\u7D3F',
    '\u7D40',
    '\u7D42',
    '\u7D44',
    '\u7D45',
    '\u7D46',
    '\u7D4E',
    '\u7D50',
    '\u7D55',
    '\u7D5B',
    '\u7D5D',
    '\u7D5E',
    '\u7D61',
    '\u7D62',
    '\u7D66',
    '\u7D68',
    '\u7D70',
    '\u7D71',
    '\u7D72',
    '\u7D73',
    '\u7D79',
    '\u7D7A',
    '\u7D80',
    '\u7D81',
    '\u7D83',
    '\u7D86',
    '\u7D87',
    '\u7D88',
    '\u7D8C',
    '\u7D8F',
    '\u7D90',
    '\u7D93',
    '\u7D9C',
    '\u7D9E',
    '\u7DA0',
    '\u7DA2',
    '\u7DA3',
    '\u7DAC',
    '\u7DAD',
    '\u7DAF',
    '\u7DB0',
    '\u7DB1',
    '\u7DB2',
    '\u7DB4',
    '\u7DB5',
    '\u7DB8',
    '\u7DB9',
    '\u7DBA',
    '\u7DBB',
    '\u7DBD',
    '\u7DBE',
    '\u7DBF',
    '\u7DC4',
    '\u7DC7',
    '\u7DCA',
    '\u7DCB',
    '\u7DCD',
    '\u7DD2',
    '\u7DD3',
    '\u7DD7',
    '\u7DD8',
    '\u7DD9',
    '\u7DDA',
    '\u7DDD',
    '\u7DDE',
    '\u7DE0',
    '\u7DE1',
    '\u7DE3',
    '\u7DE6',
    '\u7DE8',
    '\u7DE9',
    '\u7DEC',
    '\u7DEF',
    '\u7DF0',
    '\u7DF1',
    '\u7DF2',
    '\u7DF4',
    '\u7DF6',
    '\u7DF7',
    '\u7DF8',
    '\u7DF9',
    '\u7DFB',
    '\u7E08',
    '\u7E09',
    '\u7E0A',
    '\u7E0B',
    '\u7E0E',
    '\u7E10',
    '\u7E11',
    '\u7E15',
    '\u7E17',
    '\u7E1B',
    '\u7E1D',
    '\u7E1E',
    '\u7E1F',
    '\u7E23',
    '\u7E2B',
    '\u7E2C',
    '\u7E2D',
    '\u7E2E',
    '\u7E31',
    '\u7E32',
    '\u7E33',
    '\u7E35',
    '\u7E36',
    '\u7E37',
    '\u7E39',
    '\u7E3A',
    '\u7E3D',
    '\u7E3E',
    '\u7E43',
    '\u7E45',
    '\u7E46',
    '\u7E4F',
    '\u7E52',
    '\u7E53',
    '\u7E54',
    '\u7E55',
    '\u7E5A',
    '\u7E5E',
    '\u7E5F',
    '\u7E61',
    '\u7E62',
    '\u7E69',
    '\u7E6A',
    '\u7E6B',
    '\u7E6D',
    '\u7E6F',
    '\u7E70',
    '\u7E73',
    '\u7E78',
    '\u7E79',
    '\u7E7B',
    '\u7E7C',
    '\u7E7D',
    '\u7E7E',
    '\u7E7F',
    '\u7E81',
    '\u7E87',
    '\u7E88',
    '\u7E8A',
    '\u7E8C',
    '\u7E8D',
    '\u7E8F',
    '\u7E93',
    '\u7E96',
    '\u7E98',
    '\u7E9C',
    '\u7F3D',
    '\u7F48',
    '\u7F4C',
    '\u7F70',
    '\u7F75',
    '\u7F77',
    '\u7F85',
    '\u7F86',
    '\u7F88',
    '\u7F8B',
    '\u7FA5',
    '\u7FA9',
    '\u7FD2',
    '\u7FEC',
    '\u7FF9',
    '\u7FFD',
    '\u802C',
    '\u802E',
    '\u8056',
    '\u805E',
    '\u806F',
    '\u8070',
    '\u8072',
    '\u8073',
    '\u8075',
    '\u8076',
    '\u8077',
    '\u8079',
    '\u807D',
    '\u807E',
    '\u8085',
    '\u8105',
    '\u8108',
    '\u811B',
    '\u8125',
    '\u812B',
    '\u8139',
    '\u814E',
    '\u8156',
    '\u8161',
    '\u8166',
    '\u816A',
    '\u816B',
    '\u8173',
    '\u8178',
    '\u8183',
    '\u8195',
    '\u819A',
    '\u81A0',
    '\u81A2',
    '\u81A9',
    '\u81BD',
    '\u81BE',
    '\u81BF',
    '\u81C9',
    '\u81CD',
    '\u81CF',
    '\u81D7',
    '\u81D8',
    '\u81DA',
    '\u81DF',
    '\u81E0',
    '\u81E2',
    '\u81E8',
    '\u81FA',
    '\u8207',
    '\u8208',
    '\u8209',
    '\u820A',
    '\u8259',
    '\u8264',
    '\u8266',
    '\u826B',
    '\u8271',
    '\u8277',
    '\u82BB',
    '\u82E7',
    '\u8332',
    '\u834A',
    '\u838A',
    '\u8396',
    '\u83A2',
    '\u83A7',
    '\u83EF',
    '\u8407',
    '\u840A',
    '\u842C',
    '\u8434',
    '\u8435',
    '\u8449',
    '\u8452',
    '\u8457',
    '\u8464',
    '\u8466',
    '\u8477',
    '\u8494',
    '\u849E',
    '\u84BC',
    '\u84C0',
    '\u84CB',
    '\u84EE',
    '\u84EF',
    '\u84F4',
    '\u84FD',
    '\u851E',
    '\u8523',
    '\u8525',
    '\u8526',
    '\u852D',
    '\u8541',
    '\u8546',
    '\u854E',
    '\u8552',
    '\u8553',
    '\u8555',
    '\u8558',
    '\u8562',
    '\u8569',
    '\u856A',
    '\u856D',
    '\u8577',
    '\u8580',
    '\u8588',
    '\u858A',
    '\u858C',
    '\u8594',
    '\u8598',
    '\u859F',
    '\u85A6',
    '\u85A9',
    '\u85B3',
    '\u85B4',
    '\u85BA',
    '\u85CD',
    '\u85CE',
    '\u85DD',
    '\u85E5',
    '\u85EA',
    '\u85F6',
    '\u85F9',
    '\u85FA',
    '\u8604',
    '\u8606',
    '\u8607',
    '\u860A',
    '\u860B',
    '\u861A',
    '\u861E',
    '\u8622',
    '\u862D',
    '\u863A',
    '\u863F',
    '\u8646',
    '\u8655',
    '\u865B',
    '\u865C',
    '\u865F',
    '\u8667',
    '\u866F',
    '\u86FA',
    '\u86FB',
    '\u8706',
    '\u8721',
    '\u8755',
    '\u875F',
    '\u8766',
    '\u8778',
    '\u8784',
    '\u879E',
    '\u87A2',
    '\u87AE',
    '\u87BB',
    '\u87BF',
    '\u87C4',
    '\u87C8',
    '\u87CE',
    '\u87E3',
    '\u87EC',
    '\u87EF',
    '\u87F2',
    '\u87F6',
    '\u87FB',
    '\u8801',
    '\u8805',
    '\u8806',
    '\u8810',
    '\u8811',
    '\u881F',
    '\u8823',
    '\u8828',
    '\u8831',
    '\u8836',
    '\u883B',
    '\u8853',
    '\u8855',
    '\u885A',
    '\u885B',
    '\u885D',
    '\u889E',
    '\u88CA',
    '\u88DC',
    '\u88DD',
    '\u88E1',
    '\u88FD',
    '\u8907',
    '\u890C',
    '\u8918',
    '\u8932',
    '\u8933',
    '\u8938',
    '\u893B',
    '\u8940',
    '\u8949',
    '\u894F',
    '\u8956',
    '\u895D',
    '\u8960',
    '\u8964',
    '\u896A',
    '\u896C',
    '\u896F',
    '\u8972',
    '\u8974',
    '\u8986',
    '\u898B',
    '\u898E',
    '\u898F',
    '\u8993',
    '\u8996',
    '\u8998',
    '\u89A1',
    '\u89A5',
    '\u89A6',
    '\u89AA',
    '\u89AC',
    '\u89AF',
    '\u89B2',
    '\u89B7',
    '\u89BA',
    '\u89BC',
    '\u89BD',
    '\u89BF',
    '\u89C0',
    '\u89F4',
    '\u89F6',
    '\u89F8',
    '\u8A01',
    '\u8A02',
    '\u8A03',
    '\u8A08',
    '\u8A0A',
    '\u8A0C',
    '\u8A0E',
    '\u8A10',
    '\u8A11',
    '\u8A12',
    '\u8A13',
    '\u8A15',
    '\u8A16',
    '\u8A17',
    '\u8A18',
    '\u8A1B',
    '\u8A1D',
    '\u8A1F',
    '\u8A22',
    '\u8A23',
    '\u8A25',
    '\u8A29',
    '\u8A2A',
    '\u8A2D',
    '\u8A31',
    '\u8A34',
    '\u8A36',
    '\u8A3A',
    '\u8A3B',
    '\u8A40',
    '\u8A41',
    '\u8A46',
    '\u8A4E',
    '\u8A50',
    '\u8A51',
    '\u8A52',
    '\u8A54',
    '\u8A55',
    '\u8A56',
    '\u8A57',
    '\u8A58',
    '\u8A5B',
    '\u8A5E',
    '\u8A60',
    '\u8A61',
    '\u8A62',
    '\u8A63',
    '\u8A66',
    '\u8A69',
    '\u8A6B',
    '\u8A6C',
    '\u8A6D',
    '\u8A6E',
    '\u8A70',
    '\u8A71',
    '\u8A72',
    '\u8A73',
    '\u8A75',
    '\u8A7C',
    '\u8A7F',
    '\u8A84',
    '\u8A85',
    '\u8A86',
    '\u8A87',
    '\u8A8C',
    '\u8A8D',
    '\u8A91',
    '\u8A92',
    '\u8A95',
    '\u8A98',
    '\u8A9A',
    '\u8A9E',
    '\u8AA0',
    '\u8AA1',
    '\u8AA3',
    '\u8AA4',
    '\u8AA5',
    '\u8AA6',
    '\u8AA8',
    '\u8AAA',
    '\u8AB0',
    '\u8AB2',
    '\u8AB6',
    '\u8AB9',
    '\u8ABC',
    '\u8ABE',
    '\u8ABF',
    '\u8AC2',
    '\u8AC4',
    '\u8AC7',
    '\u8AC9',
    '\u8ACB',
    '\u8ACD',
    '\u8ACF',
    '\u8AD1',
    '\u8AD2',
    '\u8AD6',
    '\u8AD7',
    '\u8ADB',
    '\u8ADC',
    '\u8ADD',
    '\u8ADE',
    '\u8AE2',
    '\u8AE4',
    '\u8AE6',
    '\u8AE7',
    '\u8AEB',
    '\u8AED',
    '\u8AEE',
    '\u8AF0',
    '\u8AF1',
    '\u8AF3',
    '\u8AF6',
    '\u8AF7',
    '\u8AF8',
    '\u8AFA',
    '\u8AFC',
    '\u8AFE',
    '\u8B00',
    '\u8B01',
    '\u8B02',
    '\u8B04',
    '\u8B05',
    '\u8B0A',
    '\u8B0E',
    '\u8B0F',
    '\u8B10',
    '\u8B14',
    '\u8B16',
    '\u8B17',
    '\u8B19',
    '\u8B1A',
    '\u8B1B',
    '\u8B1D',
    '\u8B20',
    '\u8B28',
    '\u8B2B',
    '\u8B2C',
    '\u8B33',
    '\u8B39',
    '\u8B3E',
    '\u8B49',
    '\u8B4A',
    '\u8B4E',
    '\u8B4F',
    '\u8B56',
    '\u8B58',
    '\u8B59',
    '\u8B5A',
    '\u8B5C',
    '\u8B6B',
    '\u8B6F',
    '\u8B70',
    '\u8B74',
    '\u8B77',
    '\u8B78',
    '\u8B7D',
    '\u8B7E',
    '\u8B80',
    '\u8B8A',
    '\u8B8B',
    '\u8B8C',
    '\u8B8E',
    '\u8B92',
    '\u8B93',
    '\u8B95',
    '\u8B96',
    '\u8B9C',
    '\u8B9E',
    '\u8C48',
    '\u8C4E',
    '\u8C50',
    '\u8C6C',
    '\u8C76',
    '\u8C93',
    '\u8C99',
    '\u8C9D',
    '\u8C9E',
    '\u8C9F',
    '\u8CA0',
    '\u8CA1',
    '\u8CA2',
    '\u8CA7',
    '\u8CA8',
    '\u8CA9',
    '\u8CAA',
    '\u8CAB',
    '\u8CAC',
    '\u8CAF',
    '\u8CB0',
    '\u8CB2',
    '\u8CB3',
    '\u8CB4',
    '\u8CB6',
    '\u8CB7',
    '\u8CB8',
    '\u8CBA',
    '\u8CBB',
    '\u8CBC',
    '\u8CBD',
    '\u8CBF',
    '\u8CC0',
    '\u8CC1',
    '\u8CC2',
    '\u8CC3',
    '\u8CC4',
    '\u8CC5',
    '\u8CC7',
    '\u8CC8',
    '\u8CCA',
    '\u8CD1',
    '\u8CD2',
    '\u8CD3',
    '\u8CD5',
    '\u8CD9',
    '\u8CDA',
    '\u8CDC',
    '\u8CDE',
    '\u8CDF',
    '\u8CE0',
    '\u8CE1',
    '\u8CE2',
    '\u8CE3',
    '\u8CE4',
    '\u8CE6',
    '\u8CE7',
    '\u8CEA',
    '\u8CEC',
    '\u8CED',
    '\u8CF0',
    '\u8CF4',
    '\u8CF5',
    '\u8CFA',
    '\u8CFB',
    '\u8CFC',
    '\u8CFD',
    '\u8CFE',
    '\u8D03',
    '\u8D04',
    '\u8D05',
    '\u8D07',
    '\u8D08',
    '\u8D0A',
    '\u8D0D',
    '\u8D0F',
    '\u8D10',
    '\u8D13',
    '\u8D14',
    '\u8D16',
    '\u8D17',
    '\u8D1B',
    '\u8D6C',
    '\u8D95',
    '\u8D99',
    '\u8DA8',
    '\u8DB2',
    '\u8DE1',
    '\u8E10',
    '\u8E34',
    '\u8E4C',
    '\u8E55',
    '\u8E63',
    '\u8E64',
    '\u8E7A',
    '\u8E7B',
    '\u8E82',
    '\u8E89',
    '\u8E8A',
    '\u8E8B',
    '\u8E8D',
    '\u8E8E',
    '\u8E91',
    '\u8E92',
    '\u8E93',
    '\u8E95',
    '\u8E9A',
    '\u8E9D',
    '\u8EA1',
    '\u8EA5',
    '\u8EA6',
    '\u8EAA',
    '\u8EC0',
    '\u8EC9',
    '\u8ECA',
    '\u8ECB',
    '\u8ECC',
    '\u8ECD',
    '\u8ECF',
    '\u8ED1',
    '\u8ED2',
    '\u8ED4',
    '\u8ED7',
    '\u8EDB',
    '\u8EDF',
    '\u8EE4',
    '\u8EE8',
    '\u8EEB',
    '\u8EF2',
    '\u8EF8',
    '\u8EF9',
    '\u8EFA',
    '\u8EFB',
    '\u8EFC',
    '\u8EFE',
    '\u8F03',
    '\u8F04',
    '\u8F05',
    '\u8F07',
    '\u8F08',
    '\u8F09',
    '\u8F0A',
    '\u8F12',
    '\u8F13',
    '\u8F14',
    '\u8F15',
    '\u8F17',
    '\u8F1B',
    '\u8F1C',
    '\u8F1D',
    '\u8F1E',
    '\u8F1F',
    '\u8F25',
    '\u8F26',
    '\u8F29',
    '\u8F2A',
    '\u8F2C',
    '\u8F2E',
    '\u8F2F',
    '\u8F33',
    '\u8F38',
    '\u8F3B',
    '\u8F3E',
    '\u8F3F',
    '\u8F40',
    '\u8F42',
    '\u8F44',
    '\u8F45',
    '\u8F46',
    '\u8F49',
    '\u8F4D',
    '\u8F4E',
    '\u8F54',
    '\u8F5F',
    '\u8F61',
    '\u8F62',
    '\u8F63',
    '\u8F64',
    '\u8FA6',
    '\u8FAD',
    '\u8FAE',
    '\u8FAF',
    '\u8FB2',
    '\u9015',
    '\u9019',
    '\u9023',
    '\u9032',
    '\u904B',
    '\u904E',
    '\u9054',
    '\u9055',
    '\u9059',
    '\u905C',
    '\u905E',
    '\u9060',
    '\u9069',
    '\u9072',
    '\u9077',
    '\u9078',
    '\u907A',
    '\u907C',
    '\u9081',
    '\u9084',
    '\u9087',
    '\u908A',
    '\u908F',
    '\u9090',
    '\u90DF',
    '\u90F5',
    '\u9106',
    '\u9109',
    '\u9112',
    '\u9114',
    '\u9116',
    '\u9127',
    '\u912D',
    '\u9130',
    '\u9132',
    '\u9134',
    '\u9136',
    '\u913A',
    '\u9147',
    '\u9148',
    '\u919C',
    '\u919E',
    '\u91AB',
    '\u91AC',
    '\u91B1',
    '\u91C0',
    '\u91C1',
    '\u91C3',
    '\u91C5',
    '\u91CB',
    '\u91D0',
    '\u91D2',
    '\u91D3',
    '\u91D4',
    '\u91D5',
    '\u91D7',
    '\u91D8',
    '\u91D9',
    '\u91DD',
    '\u91E3',
    '\u91E4',
    '\u91E7',
    '\u91E9',
    '\u91F3',
    '\u91F5',
    '\u91F7',
    '\u91F9',
    '\u91FA',
    '\u91FE',
    '\u9200',
    '\u9201',
    '\u9203',
    '\u9204',
    '\u9207',
    '\u9208',
    '\u9209',
    '\u920B',
    '\u920D',
    '\u9210',
    '\u9211',
    '\u9212',
    '\u9214',
    '\u9215',
    '\u921E',
    '\u9220',
    '\u9223',
    '\u9225',
    '\u9226',
    '\u9227',
    '\u922E',
    '\u922F',
    '\u9230',
    '\u9232',
    '\u9233',
    '\u9234',
    '\u9237',
    '\u9238',
    '\u9239',
    '\u923A',
    '\u923D',
    '\u923E',
    '\u923F',
    '\u9240',
    '\u9241',
    '\u9245',
    '\u9248',
    '\u9249',
    '\u924B',
    '\u924D',
    '\u9251',
    '\u9255',
    '\u9257',
    '\u925A',
    '\u925B',
    '\u925E',
    '\u9264',
    '\u9266',
    '\u926C',
    '\u926D',
    '\u9276',
    '\u9278',
    '\u927A',
    '\u927B',
    '\u927F',
    '\u9280',
    '\u9283',
    '\u9285',
    '\u928D',
    '\u9291',
    '\u9293',
    '\u9296',
    '\u9298',
    '\u929A',
    '\u929B',
    '\u929C',
    '\u92A0',
    '\u92A3',
    '\u92A5',
    '\u92A6',
    '\u92A8',
    '\u92A9',
    '\u92AA',
    '\u92AB',
    '\u92AC',
    '\u92B1',
    '\u92B3',
    '\u92B6',
    '\u92B7',
    '\u92BB',
    '\u92BC',
    '\u92C1',
    '\u92C3',
    '\u92C5',
    '\u92C7',
    '\u92C9',
    '\u92CC',
    '\u92CF',
    '\u92D2',
    '\u92D9',
    '\u92DD',
    '\u92DF',
    '\u92E3',
    '\u92E4',
    '\u92E5',
    '\u92E6',
    '\u92E8',
    '\u92E9',
    '\u92EA',
    '\u92EE',
    '\u92EF',
    '\u92F0',
    '\u92F1',
    '\u92F6',
    '\u92F8',
    '\u92FC',
    '\u9301',
    '\u9302',
    '\u9304',
    '\u9306',
    '\u9307',
    '\u9308',
    '\u930F',
    '\u9310',
    '\u9312',
    '\u9315',
    '\u9318',
    '\u9319',
    '\u931A',
    '\u931B',
    '\u931F',
    '\u9320',
    '\u9321',
    '\u9322',
    '\u9326',
    '\u9328',
    '\u9329',
    '\u932B',
    '\u932E',
    '\u932F',
    '\u9333',
    '\u9336',
    '\u9338',
    '\u9340',
    '\u9343',
    '\u9344',
    '\u9346',
    '\u9347',
    '\u9348',
    '\u934B',
    '\u934D',
    '\u9354',
    '\u9358',
    '\u935A',
    '\u935B',
    '\u9360',
    '\u9364',
    '\u9365',
    '\u9369',
    '\u936C',
    '\u936E',
    '\u9370',
    '\u9375',
    '\u9376',
    '\u937A',
    '\u937E',
    '\u9382',
    '\u9384',
    '\u9387',
    '\u938A',
    '\u9394',
    '\u9396',
    '\u9398',
    '\u939B',
    '\u939D',
    '\u93A1',
    '\u93A2',
    '\u93A3',
    '\u93A6',
    '\u93A7',
    '\u93A9',
    '\u93AA',
    '\u93AC',
    '\u93AE',
    '\u93AF',
    '\u93B0',
    '\u93B2',
    '\u93B3',
    '\u93B5',
    '\u93B7',
    '\u93BF',
    '\u93C3',
    '\u93C6',
    '\u93C7',
    '\u93C8',
    '\u93C9',
    '\u93CC',
    '\u93CD',
    '\u93D0',
    '\u93D1',
    '\u93D7',
    '\u93D8',
    '\u93DC',
    '\u93DD',
    '\u93DE',
    '\u93DF',
    '\u93E1',
    '\u93E2',
    '\u93E4',
    '\u93E6',
    '\u93E8',
    '\u93F0',
    '\u93F5',
    '\u93F7',
    '\u93F9',
    '\u93FA',
    '\u93FD',
    '\u9403',
    '\u9404',
    '\u940B',
    '\u940D',
    '\u940E',
    '\u940F',
    '\u9410',
    '\u9412',
    '\u9413',
    '\u9414',
    '\u9418',
    '\u9419',
    '\u9420',
    '\u9425',
    '\u9426',
    '\u9427',
    '\u9428',
    '\u942B',
    '\u942E',
    '\u942F',
    '\u9432',
    '\u9433',
    '\u9435',
    '\u9436',
    '\u9438',
    '\u943A',
    '\u943F',
    '\u9444',
    '\u944A',
    '\u944C',
    '\u9452',
    '\u9454',
    '\u9455',
    '\u945E',
    '\u9460',
    '\u9463',
    '\u9465',
    '\u946D',
    '\u9470',
    '\u9471',
    '\u9472',
    '\u9477',
    '\u9479',
    '\u947C',
    '\u947D',
    '\u947E',
    '\u947F',
    '\u9481',
    '\u9577',
    '\u9580',
    '\u9582',
    '\u9583',
    '\u9586',
    '\u9588',
    '\u9589',
    '\u958B',
    '\u958C',
    '\u958D',
    '\u958E',
    '\u958F',
    '\u9590',
    '\u9591',
    '\u9593',
    '\u9594',
    '\u9598',
    '\u95A1',
    '\u95A3',
    '\u95A5',
    '\u95A8',
    '\u95A9',
    '\u95AB',
    '\u95AC',
    '\u95AD',
    '\u95B1',
    '\u95B6',
    '\u95B9',
    '\u95BB',
    '\u95BC',
    '\u95BD',
    '\u95BE',
    '\u95BF',
    '\u95C3',
    '\u95C6',
    '\u95C8',
    '\u95CA',
    '\u95CB',
    '\u95CC',
    '\u95CD',
    '\u95D0',
    '\u95D2',
    '\u95D3',
    '\u95D4',
    '\u95D5',
    '\u95D6',
    '\u95DC',
    '\u95DE',
    '\u95E0',
    '\u95E1',
    '\u95E4',
    '\u95E5',
    '\u962A',
    '\u9658',
    '\u965D',
    '\u9663',
    '\u9670',
    '\u9673',
    '\u9678',
    '\u967D',
    '\u9689',
    '\u968A',
    '\u968E',
    '\u9695',
    '\u969B',
    '\u96A8',
    '\u96AA',
    '\u96B1',
    '\u96B4',
    '\u96B8',
    '\u96BB',
    '\u96CB',
    '\u96D6',
    '\u96D9',
    '\u96DB',
    '\u96DC',
    '\u96DE',
    '\u96E2',
    '\u96E3',
    '\u96F2',
    '\u96FB',
    '\u9722',
    '\u9727',
    '\u973D',
    '\u9742',
    '\u9744',
    '\u9748',
    '\u975A',
    '\u975C',
    '\u9766',
    '\u9768',
    '\u9780',
    '\u978F',
    '\u979D',
    '\u97BD',
    '\u97C1',
    '\u97C3',
    '\u97C9',
    '\u97CB',
    '\u97CC',
    '\u97CD',
    '\u97D3',
    '\u97D9',
    '\u97DC',
    '\u97DE',
    '\u97FB',
    '\u97FF',
    '\u9801',
    '\u9802',
    '\u9803',
    '\u9805',
    '\u9806',
    '\u9807',
    '\u9808',
    '\u980A',
    '\u980C',
    '\u980E',
    '\u980F',
    '\u9810',
    '\u9811',
    '\u9812',
    '\u9813',
    '\u9817',
    '\u9818',
    '\u981C',
    '\u9821',
    '\u9824',
    '\u9826',
    '\u982D',
    '\u982E',
    '\u9830',
    '\u9832',
    '\u9834',
    '\u9837',
    '\u9838',
    '\u9839',
    '\u983B',
    '\u9843',
    '\u9846',
    '\u984C',
    '\u984D',
    '\u984E',
    '\u984F',
    '\u9852',
    '\u9853',
    '\u9858',
    '\u9859',
    '\u985B',
    '\u985E',
    '\u9862',
    '\u9865',
    '\u9867',
    '\u986B',
    '\u986C',
    '\u986F',
    '\u9870',
    '\u9871',
    '\u9873',
    '\u9874',
    '\u98A8',
    '\u98AD',
    '\u98AE',
    '\u98AF',
    '\u98B0',
    '\u98B1',
    '\u98B3',
    '\u98B6',
    '\u98B7',
    '\u98B8',
    '\u98BA',
    '\u98BB',
    '\u98BC',
    '\u98BE',
    '\u98C0',
    '\u98C4',
    '\u98C6',
    '\u98C8',
    '\u98DB',
    '\u98E0',
    '\u98E2',
    '\u98E3',
    '\u98E5',
    '\u98E9',
    '\u98EA',
    '\u98EB',
    '\u98ED',
    '\u98EF',
    '\u98F2',
    '\u98F4',
    '\u98FC',
    '\u98FD',
    '\u98FE',
    '\u98FF',
    '\u9903',
    '\u9904',
    '\u9905',
    '\u9909',
    '\u990A',
    '\u990C',
    '\u990E',
    '\u990F',
    '\u9911',
    '\u9912',
    '\u9913',
    '\u9914',
    '\u9915',
    '\u9916',
    '\u9917',
    '\u9918',
    '\u991A',
    '\u991B',
    '\u991C',
    '\u991E',
    '\u9921',
    '\u9926',
    '\u9928',
    '\u992D',
    '\u9931',
    '\u9933',
    '\u9936',
    '\u9937',
    '\u9938',
    '\u993A',
    '\u993C',
    '\u993E',
    '\u993F',
    '\u9941',
    '\u9943',
    '\u9945',
    '\u9948',
    '\u9949',
    '\u994A',
    '\u994B',
    '\u994C',
    '\u9952',
    '\u9957',
    '\u9958',
    '\u995C',
    '\u995E',
    '\u9962',
    '\u99AC',
    '\u99AD',
    '\u99AE',
    '\u99B1',
    '\u99B3',
    '\u99B4',
    '\u99B9',
    '\u99C1',
    '\u99C3',
    '\u99CE',
    '\u99D0',
    '\u99D1',
    '\u99D2',
    '\u99D4',
    '\u99D5',
    '\u99D8',
    '\u99D9',
    '\u99DA',
    '\u99DB',
    '\u99DD',
    '\u99DF',
    '\u99E2',
    '\u99E7',
    '\u99E9',
    '\u99ED',
    '\u99F0',
    '\u99F1',
    '\u99F6',
    '\u99F8',
    '\u99FB',
    '\u99FF',
    '\u9A01',
    '\u9A02',
    '\u9A03',
    '\u9A05',
    '\u9A0C',
    '\u9A0D',
    '\u9A0E',
    '\u9A0F',
    '\u9A14',
    '\u9A16',
    '\u9A19',
    '\u9A1A',
    '\u9A1D',
    '\u9A1F',
    '\u9A20',
    '\u9A24',
    '\u9A27',
    '\u9A2A',
    '\u9A2B',
    '\u9A2D',
    '\u9A2E',
    '\u9A30',
    '\u9A36',
    '\u9A37',
    '\u9A38',
    '\u9A3E',
    '\u9A40',
    '\u9A41',
    '\u9A42',
    '\u9A43',
    '\u9A44',
    '\u9A45',
    '\u9A4A',
    '\u9A4B',
    '\u9A4C',
    '\u9A4D',
    '\u9A4F',
    '\u9A55',
    '\u9A57',
    '\u9A5A',
    '\u9A5B',
    '\u9A5F',
    '\u9A62',
    '\u9A64',
    '\u9A65',
    '\u9A66',
    '\u9A6A',
    '\u9A6B',
    '\u9AAF',
    '\u9ACF',
    '\u9AD2',
    '\u9AD4',
    '\u9AD5',
    '\u9AD6',
    '\u9AEE',
    '\u9B06',
    '\u9B0D',
    '\u9B1A',
    '\u9B22',
    '\u9B25',
    '\u9B27',
    '\u9B29',
    '\u9B2E',
    '\u9B31',
    '\u9B4E',
    '\u9B58',
    '\u9B5A',
    '\u9B5B',
    '\u9B5F',
    '\u9B62',
    '\u9B65',
    '\u9B68',
    '\u9B6F',
    '\u9B74',
    '\u9B77',
    '\u9B7A',
    '\u9B81',
    '\u9B83',
    '\u9B84',
    '\u9B8A',
    '\u9B8B',
    '\u9B8D',
    '\u9B90',
    '\u9B91',
    '\u9B92',
    '\u9B93',
    '\u9B9A',
    '\u9B9C',
    '\u9B9E',
    '\u9B9F',
    '\u9BA3',
    '\u9BA6',
    '\u9BAA',
    '\u9BAB',
    '\u9BAD',
    '\u9BAE',
    '\u9BB0',
    '\u9BB3',
    '\u9BB6',
    '\u9BB8',
    '\u9BBA',
    '\u9BC0',
    '\u9BC1',
    '\u9BC4',
    '\u9BC6',
    '\u9BC7',
    '\u9BC9',
    '\u9BCA',
    '\u9BD2',
    '\u9BD4',
    '\u9BD5',
    '\u9BD6',
    '\u9BD7',
    '\u9BDB',
    '\u9BDD',
    '\u9BE1',
    '\u9BE2',
    '\u9BE4',
    '\u9BE7',
    '\u9BE8',
    '\u9BEA',
    '\u9BEB',
    '\u9BF1',
    '\u9BF4',
    '\u9BF6',
    '\u9BF7',
    '\u9BFD',
    '\u9BFF',
    '\u9C01',
    '\u9C02',
    '\u9C03',
    '\u9C06',
    '\u9C08',
    '\u9C09',
    '\u9C0C',
    '\u9C0D',
    '\u9C0F',
    '\u9C12',
    '\u9C13',
    '\u9C1C',
    '\u9C1F',
    '\u9C20',
    '\u9C23',
    '\u9C24',
    '\u9C25',
    '\u9C27',
    '\u9C28',
    '\u9C29',
    '\u9C2D',
    '\u9C2E',
    '\u9C31',
    '\u9C32',
    '\u9C33',
    '\u9C35',
    '\u9C37',
    '\u9C39',
    '\u9C3A',
    '\u9C3B',
    '\u9C3C',
    '\u9C3E',
    '\u9C42',
    '\u9C45',
    '\u9C47',
    '\u9C48',
    '\u9C49',
    '\u9C52',
    '\u9C54',
    '\u9C56',
    '\u9C57',
    '\u9C58',
    '\u9C5D',
    '\u9C5F',
    '\u9C60',
    '\u9C63',
    '\u9C64',
    '\u9C67',
    '\u9C68',
    '\u9C6D',
    '\u9C6E',
    '\u9C6F',
    '\u9C77',
    '\u9C78',
    '\u9C7A',
    '\u9CE5',
    '\u9CE7',
    '\u9CE9',
    '\u9CF2',
    '\u9CF3',
    '\u9CF4',
    '\u9CF6',
    '\u9CF7',
    '\u9CFC',
    '\u9CFE',
    '\u9D03',
    '\u9D06',
    '\u9D07',
    '\u9D09',
    '\u9D12',
    '\u9D15',
    '\u9D17',
    '\u9D1B',
    '\u9D1C',
    '\u9D1D',
    '\u9D1E',
    '\u9D1F',
    '\u9D23',
    '\u9D26',
    '\u9D28',
    '\u9D2F',
    '\u9D30',
    '\u9D32',
    '\u9D34',
    '\u9D37',
    '\u9D3B',
    '\u9D3F',
    '\u9D41',
    '\u9D42',
    '\u9D43',
    '\u9D50',
    '\u9D51',
    '\u9D52',
    '\u9D53',
    '\u9D5A',
    '\u9D5C',
    '\u9D5D',
    '\u9D60',
    '\u9D61',
    '\u9D6A',
    '\u9D6C',
    '\u9D6E',
    '\u9D6F',
    '\u9D72',
    '\u9D77',
    '\u9D7E',
    '\u9D84',
    '\u9D87',
    '\u9D89',
    '\u9D8A',
    '\u9D92',
    '\u9D93',
    '\u9D96',
    '\u9D97',
    '\u9D98',
    '\u9D9A',
    '\u9DA1',
    '\u9DA5',
    '\u9DA9',
    '\u9DAA',
    '\u9DAC',
    '\u9DAF',
    '\u9DB2',
    '\u9DB4',
    '\u9DB9',
    '\u9DBA',
    '\u9DBB',
    '\u9DBC',
    '\u9DBF',
    '\u9DC1',
    '\u9DC2',
    '\u9DC8',
    '\u9DCA',
    '\u9DD3',
    '\u9DD4',
    '\u9DD6',
    '\u9DD7',
    '\u9DD9',
    '\u9DDA',
    '\u9DE5',
    '\u9DE6',
    '\u9DE8',
    '\u9DEB',
    '\u9DEF',
    '\u9DF2',
    '\u9DF3',
    '\u9DF8',
    '\u9DF9',
    '\u9DFA',
    '\u9DFD',
    '\u9DFF',
    '\u9E02',
    '\u9E07',
    '\u9E0B',
    '\u9E0C',
    '\u9E0F',
    '\u9E15',
    '\u9E18',
    '\u9E1A',
    '\u9E1B',
    '\u9E1D',
    '\u9E1E',
    '\u9E75',
    '\u9E79',
    '\u9E7A',
    '\u9E7C',
    '\u9E7D',
    '\u9E97',
    '\u9EA5',
    '\u9EA8',
    '\u9EA9',
    '\u9EB2',
    '\u9EB5',
    '\u9EBC',
    '\u9EBD',
    '\u9EC3',
    '\u9ECC',
    '\u9EDE',
    '\u9EE8',
    '\u9EF2',
    '\u9EF6',
    '\u9EF7',
    '\u9EFD',
    '\u9EFF',
    '\u9F09',
    '\u9F34',
    '\u9F4A',
    '\u9F4B',
    '\u9F4E',
    '\u9F4F',
    '\u9F52',
    '\u9F54',
    '\u9F55',
    '\u9F57',
    '\u9F59',
    '\u9F5C',
    '\u9F5F',
    '\u9F60',
    '\u9F61',
    '\u9F66',
    '\u9F6A',
    '\u9F6C',
    '\u9F72',
    '\u9F76',
    '\u9F77',
    '\u9F8D',
    '\u9F8E',
    '\u9F90',
    '\u9F91',
    '\u9F94',
    '\u9F95',
    '\u9F9C',
    '\u9FAD',
    '\u9FAF']
  end

  def simplified_chinese_characters
    [ '\u343D',
    '\u3447',
    '\u3448',
    '\u3454',
    '\u3469',
    '\u34E5',
    '\u3509',
    '\u358A',
    '\u359E',
    '\u360E',
    '\u36AF',
    '\u36C0',
    '\u36DF',
    '\u36E0',
    '\u36E3',
    '\u36E4',
    '\u36FF',
    '\u37C6',
    '\u37DC',
    '\u3918',
    '\u39CF',
    '\u39D0',
    '\u39D1',
    '\u39DF',
    '\u39F0',
    '\u3A2B',
    '\u3B4E',
    '\u3B4F',
    '\u3B63',
    '\u3B64',
    '\u3B74',
    '\u3C69',
    '\u3C6E',
    '\u3CBF',
    '\u3CD4',
    '\u3CD5',
    '\u3CE0',
    '\u3CE1',
    '\u3CE2',
    '\u3CFD',
    '\u3D89',
    '\u3DB6',
    '\u3DBD',
    '\u3E8D',
    '\u3EC5',
    '\u3ECF',
    '\u3ED8',
    '\u4025',
    '\u4056',
    '\u40B5',
    '\u4149',
    '\u416A',
    '\u41F2',
    '\u4264',
    '\u4336',
    '\u4337',
    '\u4338',
    '\u4339',
    '\u433A',
    '\u433B',
    '\u433C',
    '\u433D',
    '\u433E',
    '\u4340',
    '\u4341',
    '\u44D5',
    '\u45D6',
    '\u461B',
    '\u461E',
    '\u464A',
    '\u464C',
    '\u4653',
    '\u4723',
    '\u4725',
    '\u4727',
    '\u4729',
    '\u4759',
    '\u478C',
    '\u478D',
    '\u478E',
    '\u4790',
    '\u47E2',
    '\u4880',
    '\u4881',
    '\u4882',
    '\u497A',
    '\u497D',
    '\u497E',
    '\u497F',
    '\u4980',
    '\u4981',
    '\u4982',
    '\u4983',
    '\u4985',
    '\u49B6',
    '\u49B7',
    '\u4B6A',
    '\u4BC3',
    '\u4BC4',
    '\u4BC5',
    '\u4C9D',
    '\u4C9E',
    '\u4C9F',
    '\u4CA0',
    '\u4CA1',
    '\u4CA2',
    '\u4CA3',
    '\u4D13',
    '\u4D14',
    '\u4D15',
    '\u4D16',
    '\u4D17',
    '\u4D18',
    '\u4D19',
    '\u4DAE',
    '\u4E07',
    '\u4E0E',
    '\u4E11',
    '\u4E13',
    '\u4E1A',
    '\u4E1B',
    '\u4E1C',
    '\u4E1D',
    '\u4E22',
    '\u4E24',
    '\u4E25',
    '\u4E27',
    '\u4E2A',
    '\u4E30',
    '\u4E34',
    '\u4E3A',
    '\u4E3D',
    '\u4E3E',
    '\u4E48',
    '\u4E49',
    '\u4E4C',
    '\u4E50',
    '\u4E54',
    '\u4E60',
    '\u4E61',
    '\u4E66',
    '\u4E70',
    '\u4E71',
    '\u4E89',
    '\u4E8E',
    '\u4E8F',
    '\u4E91',
    '\u4E9A',
    '\u4EA7',
    '\u4EA9',
    '\u4EB2',
    '\u4EB5',
    '\u4EB8',
    '\u4EBF',
    '\u4EC5',
    '\u4EC6',
    '\u4ECE',
    '\u4ED1',
    '\u4ED3',
    '\u4EEA',
    '\u4EEC',
    '\u4EF7',
    '\u4F17',
    '\u4F18',
    '\u4F1A',
    '\u4F1B',
    '\u4F1E',
    '\u4F1F',
    '\u4F20',
    '\u4F21',
    '\u4F23',
    '\u4F24',
    '\u4F25',
    '\u4F26',
    '\u4F27',
    '\u4F2A',
    '\u4F2B',
    '\u4F53',
    '\u4F59',
    '\u4F63',
    '\u4F65',
    '\u4FA0',
    '\u4FA3',
    '\u4FA5',
    '\u4FA6',
    '\u4FA7',
    '\u4FA8',
    '\u4FA9',
    '\u4FAA',
    '\u4FAC',
    '\u4FE3',
    '\u4FE6',
    '\u4FE8',
    '\u4FE9',
    '\u4FEA',
    '\u4FEB',
    '\u4FED',
    '\u503A',
    '\u503E',
    '\u506C',
    '\u507B',
    '\u507E',
    '\u507F',
    '\u50A5',
    '\u50A7',
    '\u50A8',
    '\u50A9',
    '\u50DE',
    '\u513F',
    '\u514B',
    '\u5151',
    '\u5156',
    '\u515A',
    '\u5170',
    '\u5173',
    '\u5174',
    '\u5179',
    '\u517B',
    '\u517D',
    '\u5181',
    '\u5185',
    '\u5188',
    '\u518C',
    '\u5199',
    '\u519B',
    '\u519C',
    '\u51AF',
    '\u51B2',
    '\u51B3',
    '\u51B5',
    '\u51BB',
    '\u51C0',
    '\u51C6',
    '\u51C9',
    '\u51CF',
    '\u51D1',
    '\u51DB',
    '\u51E0',
    '\u51E4',
    '\u51EB',
    '\u51ED',
    '\u51EF',
    '\u51FB',
    '\u51FF',
    '\u520D',
    '\u5212',
    '\u5218',
    '\u5219',
    '\u521A',
    '\u521B',
    '\u5220',
    '\u522B',
    '\u522C',
    '\u522D',
    '\u522E',
    '\u5236',
    '\u5239',
    '\u523D',
    '\u523E',
    '\u523F',
    '\u5240',
    '\u5242',
    '\u5250',
    '\u5251',
    '\u5265',
    '\u5267',
    '\u529D',
    '\u529E',
    '\u52A1',
    '\u52A2',
    '\u52A8',
    '\u52B1',
    '\u52B2',
    '\u52B3',
    '\u52BF',
    '\u52CB',
    '\u52DA',
    '\u5300',
    '\u5326',
    '\u532E',
    '\u533A',
    '\u533B',
    '\u534E',
    '\u534F',
    '\u5355',
    '\u5356',
    '\u5362',
    '\u5364',
    '\u536B',
    '\u5374',
    '\u5382',
    '\u5385',
    '\u5386',
    '\u5389',
    '\u538B',
    '\u538C',
    '\u538D',
    '\u5390',
    '\u5395',
    '\u5398',
    '\u53A2',
    '\u53A3',
    '\u53A6',
    '\u53A8',
    '\u53A9',
    '\u53AE',
    '\u53BF',
    '\u53C1',
    '\u53C2',
    '\u53CC',
    '\u53D1',
    '\u53D8',
    '\u53D9',
    '\u53E0',
    '\u53EA',
    '\u53F0',
    '\u53F6',
    '\u53F7',
    '\u53F9',
    '\u53FD',
    '\u540C',
    '\u540E',
    '\u5411',
    '\u5413',
    '\u5415',
    '\u5417',
    '\u5423',
    '\u5428',
    '\u542C',
    '\u542F',
    '\u5434',
    '\u5450',
    '\u5452',
    '\u5453',
    '\u5455',
    '\u5456',
    '\u5457',
    '\u5458',
    '\u5459',
    '\u545B',
    '\u545C',
    '\u548F',
    '\u5499',
    '\u549B',
    '\u549D',
    '\u54A4',
    '\u54B8',
    '\u54CD',
    '\u54D1',
    '\u54D2',
    '\u54D3',
    '\u54D4',
    '\u54D5',
    '\u54D7',
    '\u54D9',
    '\u54DC',
    '\u54DD',
    '\u54DF',
    '\u551B',
    '\u551D',
    '\u5520',
    '\u5521',
    '\u5522',
    '\u5524',
    '\u5567',
    '\u556C',
    '\u556D',
    '\u556E',
    '\u556F',
    '\u5570',
    '\u5574',
    '\u5578',
    '\u55B7',
    '\u55BD',
    '\u55BE',
    '\u55EB',
    '\u55F3',
    '\u5618',
    '\u5624',
    '\u5631',
    '\u565C',
    '\u56A3',
    '\u56E2',
    '\u56ED',
    '\u56F0',
    '\u56F1',
    '\u56F4',
    '\u56F5',
    '\u56FD',
    '\u56FE',
    '\u5706',
    '\u5723',
    '\u5739',
    '\u573A',
    '\u5742',
    '\u574F',
    '\u5757',
    '\u575A',
    '\u575B',
    '\u575C',
    '\u575D',
    '\u575E',
    '\u575F',
    '\u5760',
    '\u5784',
    '\u5785',
    '\u5786',
    '\u5792',
    '\u57A6',
    '\u57A9',
    '\u57AB',
    '\u57AD',
    '\u57B1',
    '\u57B2',
    '\u57B4',
    '\u57D8',
    '\u57D9',
    '\u57DA',
    '\u57EF',
    '\u5811',
    '\u5815',
    '\u5899',
    '\u58EE',
    '\u58F0',
    '\u58F3',
    '\u58F6',
    '\u58F8',
    '\u5904',
    '\u5907',
    '\u590D',
    '\u591F',
    '\u5934',
    '\u5938',
    '\u5939',
    '\u593A',
    '\u5941',
    '\u5942',
    '\u594B',
    '\u5956',
    '\u5965',
    '\u5978',
    '\u5986',
    '\u5987',
    '\u5988',
    '\u59A9',
    '\u59AA',
    '\u59AB',
    '\u59D7',
    '\u59F9',
    '\u5A04',
    '\u5A05',
    '\u5A06',
    '\u5A07',
    '\u5A08',
    '\u5A31',
    '\u5A32',
    '\u5A34',
    '\u5A73',
    '\u5A74',
    '\u5A75',
    '\u5A76',
    '\u5AAA',
    '\u5AD2',
    '\u5AD4',
    '\u5AF1',
    '\u5B37',
    '\u5B59',
    '\u5B66',
    '\u5B6A',
    '\u5B81',
    '\u5B9D',
    '\u5B9E',
    '\u5BA0',
    '\u5BA1',
    '\u5BAA',
    '\u5BAB',
    '\u5BBD',
    '\u5BBE',
    '\u5BDD',
    '\u5BF9',
    '\u5BFB',
    '\u5BFC',
    '\u5BFF',
    '\u5C06',
    '\u5C14',
    '\u5C18',
    '\u5C1D',
    '\u5C27',
    '\u5C34',
    '\u5C38',
    '\u5C3D',
    '\u5C42',
    '\u5C43',
    '\u5C49',
    '\u5C4A',
    '\u5C5E',
    '\u5C61',
    '\u5C66',
    '\u5C7F',
    '\u5C81',
    '\u5C82',
    '\u5C96',
    '\u5C97',
    '\u5C98',
    '\u5C99',
    '\u5C9A',
    '\u5C9B',
    '\u5CAD',
    '\u5CBD',
    '\u5CBF',
    '\u5CC4',
    '\u5CE1',
    '\u5CE3',
    '\u5CE4',
    '\u5CE5',
    '\u5CE6',
    '\u5D02',
    '\u5D03',
    '\u5D04',
    '\u5D2D',
    '\u5D58',
    '\u5D5A',
    '\u5D5D',
    '\u5DC5',
    '\u5DE9',
    '\u5DEF',
    '\u5E01',
    '\u5E05',
    '\u5E08',
    '\u5E0F',
    '\u5E10',
    '\u5E18',
    '\u5E1C',
    '\u5E26',
    '\u5E27',
    '\u5E2E',
    '\u5E31',
    '\u5E3B',
    '\u5E3C',
    '\u5E42',
    '\u5E72',
    '\u5E76',
    '\u5E7F',
    '\u5E84',
    '\u5E86',
    '\u5E90',
    '\u5E91',
    '\u5E93',
    '\u5E94',
    '\u5E99',
    '\u5E9E',
    '\u5E9F',
    '\u5EEA',
    '\u5F00',
    '\u5F02',
    '\u5F03',
    '\u5F11',
    '\u5F20',
    '\u5F25',
    '\u5F2A',
    '\u5F2F',
    '\u5F39',
    '\u5F3A',
    '\u5F52',
    '\u5F53',
    '\u5F55',
    '\u5F5D',
    '\u5F66',
    '\u5F68',
    '\u5F7B',
    '\u5F81',
    '\u5F84',
    '\u5F95',
    '\u5FA1',
    '\u5FC6',
    '\u5FCF',
    '\u5FD7',
    '\u5FE7',
    '\u5FFE',
    '\u6000',
    '\u6001',
    '\u6002',
    '\u6003',
    '\u6004',
    '\u6005',
    '\u6006',
    '\u601C',
    '\u603B',
    '\u603C',
    '\u603F',
    '\u604B',
    '\u6052',
    '\u6073',
    '\u6076',
    '\u6078',
    '\u6079',
    '\u607A',
    '\u607B',
    '\u607C',
    '\u607D',
    '\u60A6',
    '\u60AB',
    '\u60AC',
    '\u60AD',
    '\u60AE',
    '\u60AF',
    '\u60CA',
    '\u60E7',
    '\u60E8',
    '\u60E9',
    '\u60EB',
    '\u60EC',
    '\u60ED',
    '\u60EE',
    '\u60EF',
    '\u6120',
    '\u6124',
    '\u6126',
    '\u613F',
    '\u6151',
    '\u61D1',
    '\u61D2',
    '\u61D4',
    '\u6206',
    '\u620B',
    '\u620F',
    '\u6217',
    '\u6218',
    '\u622C',
    '\u622F',
    '\u6237',
    '\u6251',
    '\u6267',
    '\u6269',
    '\u626A',
    '\u626B',
    '\u626C',
    '\u6270',
    '\u629A',
    '\u629B',
    '\u629F',
    '\u62A0',
    '\u62A1',
    '\u62A2',
    '\u62A4',
    '\u62A5',
    '\u62C5',
    '\u62DF',
    '\u62E2',
    '\u62E3',
    '\u62E5',
    '\u62E6',
    '\u62E7',
    '\u62E8',
    '\u62E9',
    '\u6302',
    '\u631A',
    '\u631B',
    '\u631C',
    '\u631D',
    '\u631E',
    '\u631F',
    '\u6320',
    '\u6321',
    '\u6322',
    '\u6323',
    '\u6324',
    '\u6325',
    '\u6326',
    '\u633D',
    '\u635D',
    '\u635E',
    '\u635F',
    '\u6361',
    '\u6362',
    '\u6363',
    '\u636E',
    '\u63B3',
    '\u63B4',
    '\u63B7',
    '\u63B8',
    '\u63BA',
    '\u63BC',
    '\u63FD',
    '\u63FE',
    '\u63FF',
    '\u6400',
    '\u6401',
    '\u6402',
    '\u6405',
    '\u643A',
    '\u6444',
    '\u6445',
    '\u6446',
    '\u6447',
    '\u6448',
    '\u644A',
    '\u6484',
    '\u6491',
    '\u64B5',
    '\u64B7',
    '\u64B8',
    '\u64BA',
    '\u64DE',
    '\u6512',
    '\u654C',
    '\u655B',
    '\u6569',
    '\u6570',
    '\u658B',
    '\u6593',
    '\u6597',
    '\u65A9',
    '\u65AD',
    '\u65E0',
    '\u65E7',
    '\u65F6',
    '\u65F7',
    '\u65F8',
    '\u6619',
    '\u663C',
    '\u663D',
    '\u663E',
    '\u664B',
    '\u6652',
    '\u6653',
    '\u6654',
    '\u6655',
    '\u6656',
    '\u6682',
    '\u66A7',
    '\u672F',
    '\u6734',
    '\u673A',
    '\u6740',
    '\u6742',
    '\u6743',
    '\u6746',
    '\u6761',
    '\u6765',
    '\u6768',
    '\u6769',
    '\u6770',
    '\u677E',
    '\u677F',
    '\u6781',
    '\u6784',
    '\u679E',
    '\u67A2',
    '\u67A3',
    '\u67A5',
    '\u67A7',
    '\u67A8',
    '\u67AA',
    '\u67AB',
    '\u67AD',
    '\u67DC',
    '\u67E0',
    '\u67FD',
    '\u6800',
    '\u6805',
    '\u6807',
    '\u6808',
    '\u6809',
    '\u680A',
    '\u680B',
    '\u680C',
    '\u680E',
    '\u680F',
    '\u6811',
    '\u6816',
    '\u6817',
    '\u6837',
    '\u683E',
    '\u6860',
    '\u6861',
    '\u6862',
    '\u6863',
    '\u6864',
    '\u6865',
    '\u6866',
    '\u6867',
    '\u6868',
    '\u6869',
    '\u68A6',
    '\u68BC',
    '\u68BE',
    '\u68BF',
    '\u68C0',
    '\u68C1',
    '\u68C2',
    '\u6901',
    '\u691F',
    '\u6920',
    '\u6922',
    '\u6924',
    '\u692B',
    '\u692D',
    '\u697C',
    '\u6984',
    '\u6985',
    '\u6987',
    '\u6988',
    '\u6989',
    '\u69DA',
    '\u69DB',
    '\u69DF',
    '\u69E0',
    '\u6A2A',
    '\u6A2F',
    '\u6A31',
    '\u6A65',
    '\u6A71',
    '\u6A79',
    '\u6A7C',
    '\u6AA9',
    '\u6B22',
    '\u6B24',
    '\u6B27',
    '\u6B7C',
    '\u6B81',
    '\u6B87',
    '\u6B8B',
    '\u6B92',
    '\u6B93',
    '\u6B9A',
    '\u6BA1',
    '\u6BB4',
    '\u6BC1',
    '\u6BC2',
    '\u6BD5',
    '\u6BD9',
    '\u6BE1',
    '\u6BF5',
    '\u6C07',
    '\u6C14',
    '\u6C22',
    '\u6C29',
    '\u6C32',
    '\u6C47',
    '\u6C49',
    '\u6C64',
    '\u6C79',
    '\u6C88',
    '\u6C9F',
    '\u6CA1',
    '\u6CA3',
    '\u6CA4',
    '\u6CA5',
    '\u6CA6',
    '\u6CA7',
    '\u6CA8',
    '\u6CA9',
    '\u6CAA',
    '\u6CDE',
    '\u6CE8',
    '\u6CEA',
    '\u6CF6',
    '\u6CF7',
    '\u6CF8',
    '\u6CFA',
    '\u6CFB',
    '\u6CFC',
    '\u6CFD',
    '\u6CFE',
    '\u6D01',
    '\u6D12',
    '\u6D3C',
    '\u6D43',
    '\u6D45',
    '\u6D46',
    '\u6D47',
    '\u6D48',
    '\u6D4A',
    '\u6D4B',
    '\u6D4D',
    '\u6D4E',
    '\u6D4F',
    '\u6D50',
    '\u6D51',
    '\u6D52',
    '\u6D53',
    '\u6D54',
    '\u6D55',
    '\u6D82',
    '\u6D9B',
    '\u6D9D',
    '\u6D9E',
    '\u6D9F',
    '\u6DA0',
    '\u6DA1',
    '\u6DA2',
    '\u6DA3',
    '\u6DA4',
    '\u6DA6',
    '\u6DA7',
    '\u6DA8',
    '\u6DA9',
    '\u6DC0',
    '\u6E0A',
    '\u6E0C',
    '\u6E0D',
    '\u6E0E',
    '\u6E10',
    '\u6E11',
    '\u6E14',
    '\u6E17',
    '\u6E29',
    '\u6E7E',
    '\u6E7F',
    '\u6E83',
    '\u6E85',
    '\u6E86',
    '\u6E87',
    '\u6ED7',
    '\u6EDA',
    '\u6EDE',
    '\u6EDF',
    '\u6EE0',
    '\u6EE1',
    '\u6EE2',
    '\u6EE4',
    '\u6EE5',
    '\u6EE6',
    '\u6EE8',
    '\u6EE9',
    '\u6EEA',
    '\u6F13',
    '\u6F24',
    '\u6F46',
    '\u6F47',
    '\u6F4B',
    '\u6F4D',
    '\u6F5C',
    '\u6F74',
    '\u6F9B',
    '\u6F9C',
    '\u6FD1',
    '\u6FD2',
    '\u704F',
    '\u706D',
    '\u706F',
    '\u7075',
    '\u707E',
    '\u707F',
    '\u7080',
    '\u7089',
    '\u709C',
    '\u709D',
    '\u70B9',
    '\u70BC',
    '\u70BD',
    '\u70C1',
    '\u70C2',
    '\u70C3',
    '\u70DB',
    '\u70DF',
    '\u70E6',
    '\u70E7',
    '\u70E8',
    '\u70E9',
    '\u70EB',
    '\u70EC',
    '\u70ED',
    '\u7115',
    '\u7116',
    '\u7118',
    '\u7174',
    '\u7231',
    '\u7237',
    '\u724D',
    '\u7266',
    '\u7275',
    '\u727A',
    '\u728A',
    '\u72B6',
    '\u72B7',
    '\u72B8',
    '\u72B9',
    '\u72C8',
    '\u72DD',
    '\u72DE',
    '\u72EC',
    '\u72ED',
    '\u72EE',
    '\u72EF',
    '\u72F0',
    '\u72F1',
    '\u72F2',
    '\u7303',
    '\u730E',
    '\u7315',
    '\u7321',
    '\u732A',
    '\u732B',
    '\u732C',
    '\u732E',
    '\u736D',
    '\u7391',
    '\u739A',
    '\u739B',
    '\u73AE',
    '\u73AF',
    '\u73B0',
    '\u73B1',
    '\u73BA',
    '\u73D0',
    '\u73D1',
    '\u73F0',
    '\u73F2',
    '\u740F',
    '\u7410',
    '\u743C',
    '\u7476',
    '\u7477',
    '\u748E',
    '\u74D2',
    '\u74EF',
    '\u7535',
    '\u753B',
    '\u7545',
    '\u7574',
    '\u7596',
    '\u7597',
    '\u759F',
    '\u75A0',
    '\u75A1',
    '\u75AC',
    '\u75AD',
    '\u75AE',
    '\u75AF',
    '\u75B1',
    '\u75B4',
    '\u75C7',
    '\u75C8',
    '\u75C9',
    '\u75D2',
    '\u75D6',
    '\u75E8',
    '\u75EA',
    '\u75EB',
    '\u7605',
    '\u7606',
    '\u7617',
    '\u7618',
    '\u762A',
    '\u762B',
    '\u763E',
    '\u763F',
    '\u765E',
    '\u7663',
    '\u766B',
    '\u7691',
    '\u76B1',
    '\u76B2',
    '\u76CF',
    '\u76D0',
    '\u76D1',
    '\u76D6',
    '\u76D7',
    '\u76D8',
    '\u770D',
    '\u7726',
    '\u772C',
    '\u7740',
    '\u7741',
    '\u7750',
    '\u7751',
    '\u7786',
    '\u7792',
    '\u77A9',
    '\u77EB',
    '\u77F6',
    '\u77FE',
    '\u77FF',
    '\u7800',
    '\u7801',
    '\u7816',
    '\u7817',
    '\u781A',
    '\u781C',
    '\u783A',
    '\u783B',
    '\u783E',
    '\u7840',
    '\u7841',
    '\u7855',
    '\u7856',
    '\u7857',
    '\u7859',
    '\u785A',
    '\u786E',
    '\u7875',
    '\u7877',
    '\u788D',
    '\u789B',
    '\u789C',
    '\u78B1',
    '\u793C',
    '\u7943',
    '\u794E',
    '\u7962',
    '\u796F',
    '\u7977',
    '\u7978',
    '\u7980',
    '\u7984',
    '\u7985',
    '\u79BB',
    '\u79C3',
    '\u79C6',
    '\u79CD',
    '\u79EF',
    '\u79F0',
    '\u79FD',
    '\u79FE',
    '\u7A06',
    '\u7A0E',
    '\u7A23',
    '\u7A33',
    '\u7A51',
    '\u7A77',
    '\u7A83',
    '\u7A8D',
    '\u7A8E',
    '\u7A91',
    '\u7A9C',
    '\u7A9D',
    '\u7AA5',
    '\u7AA6',
    '\u7AAD',
    '\u7AD6',
    '\u7ADE',
    '\u7B03',
    '\u7B0B',
    '\u7B14',
    '\u7B15',
    '\u7B3A',
    '\u7B3C',
    '\u7B3E',
    '\u7B51',
    '\u7B5A',
    '\u7B5B',
    '\u7B5C',
    '\u7B5D',
    '\u7B79',
    '\u7B7C',
    '\u7B7E',
    '\u7B80',
    '\u7B93',
    '\u7BA6',
    '\u7BA7',
    '\u7BA8',
    '\u7BA9',
    '\u7BAA',
    '\u7BAB',
    '\u7BD1',
    '\u7BD3',
    '\u7BEE',
    '\u7BEF',
    '\u7BF1',
    '\u7C16',
    '\u7C41',
    '\u7C74',
    '\u7C7B',
    '\u7C7C',
    '\u7C9C',
    '\u7C9D',
    '\u7CA4',
    '\u7CAA',
    '\u7CAE',
    '\u7CC1',
    '\u7CC7',
    '\u7CFB',
    '\u7D27',
    '\u7D2F',
    '\u7D77',
    '\u7E9F',
    '\u7EA0',
    '\u7EA1',
    '\u7EA2',
    '\u7EA3',
    '\u7EA4',
    '\u7EA5',
    '\u7EA6',
    '\u7EA7',
    '\u7EA8',
    '\u7EA9',
    '\u7EAA',
    '\u7EAB',
    '\u7EAC',
    '\u7EAD',
    '\u7EAE',
    '\u7EAF',
    '\u7EB0',
    '\u7EB1',
    '\u7EB2',
    '\u7EB3',
    '\u7EB4',
    '\u7EB5',
    '\u7EB6',
    '\u7EB7',
    '\u7EB8',
    '\u7EB9',
    '\u7EBA',
    '\u7EBB',
    '\u7EBC',
    '\u7EBD',
    '\u7EBE',
    '\u7EBF',
    '\u7EC0',
    '\u7EC1',
    '\u7EC2',
    '\u7EC3',
    '\u7EC4',
    '\u7EC5',
    '\u7EC6',
    '\u7EC7',
    '\u7EC8',
    '\u7EC9',
    '\u7ECA',
    '\u7ECB',
    '\u7ECC',
    '\u7ECD',
    '\u7ECE',
    '\u7ECF',
    '\u7ED0',
    '\u7ED1',
    '\u7ED2',
    '\u7ED3',
    '\u7ED4',
    '\u7ED5',
    '\u7ED6',
    '\u7ED7',
    '\u7ED8',
    '\u7ED9',
    '\u7EDA',
    '\u7EDB',
    '\u7EDC',
    '\u7EDD',
    '\u7EDE',
    '\u7EDF',
    '\u7EE0',
    '\u7EE1',
    '\u7EE2',
    '\u7EE3',
    '\u7EE4',
    '\u7EE5',
    '\u7EE6',
    '\u7EE7',
    '\u7EE8',
    '\u7EE9',
    '\u7EEA',
    '\u7EEB',
    '\u7EEC',
    '\u7EED',
    '\u7EEE',
    '\u7EEF',
    '\u7EF0',
    '\u7EF1',
    '\u7EF2',
    '\u7EF3',
    '\u7EF4',
    '\u7EF5',
    '\u7EF6',
    '\u7EF7',
    '\u7EF8',
    '\u7EF9',
    '\u7EFA',
    '\u7EFB',
    '\u7EFC',
    '\u7EFD',
    '\u7EFE',
    '\u7EFF',
    '\u7F00',
    '\u7F01',
    '\u7F02',
    '\u7F03',
    '\u7F04',
    '\u7F05',
    '\u7F06',
    '\u7F07',
    '\u7F08',
    '\u7F09',
    '\u7F0A',
    '\u7F0B',
    '\u7F0C',
    '\u7F0D',
    '\u7F0E',
    '\u7F0F',
    '\u7F11',
    '\u7F12',
    '\u7F13',
    '\u7F14',
    '\u7F15',
    '\u7F16',
    '\u7F17',
    '\u7F18',
    '\u7F19',
    '\u7F1A',
    '\u7F1B',
    '\u7F1C',
    '\u7F1D',
    '\u7F1E',
    '\u7F1F',
    '\u7F20',
    '\u7F21',
    '\u7F22',
    '\u7F23',
    '\u7F24',
    '\u7F25',
    '\u7F26',
    '\u7F27',
    '\u7F28',
    '\u7F29',
    '\u7F2A',
    '\u7F2B',
    '\u7F2C',
    '\u7F2D',
    '\u7F2E',
    '\u7F2F',
    '\u7F30',
    '\u7F31',
    '\u7F32',
    '\u7F33',
    '\u7F34',
    '\u7F35',
    '\u7F42',
    '\u7F51',
    '\u7F57',
    '\u7F5A',
    '\u7F62',
    '\u7F74',
    '\u7F81',
    '\u7F9F',
    '\u7FD8',
    '\u7FD9',
    '\u7FDA',
    '\u8022',
    '\u8027',
    '\u8038',
    '\u803B',
    '\u8042',
    '\u804B',
    '\u804C',
    '\u804D',
    '\u8054',
    '\u8069',
    '\u806A',
    '\u8083',
    '\u80A0',
    '\u80A4',
    '\u80AE',
    '\u80B4',
    '\u80BE',
    '\u80BF',
    '\u80C0',
    '\u80C1',
    '\u80C6',
    '\u80DC',
    '\u80E1',
    '\u80E7',
    '\u80E8',
    '\u80EA',
    '\u80EB',
    '\u80F6',
    '\u8109',
    '\u810D',
    '\u810F',
    '\u8110',
    '\u8111',
    '\u8113',
    '\u8114',
    '\u811A',
    '\u8131',
    '\u8136',
    '\u8138',
    '\u814A',
    '\u8158',
    '\u816D',
    '\u817B',
    '\u817C',
    '\u817D',
    '\u817E',
    '\u8191',
    '\u81DC',
    '\u81F4',
    '\u8206',
    '\u820D',
    '\u8223',
    '\u8230',
    '\u8231',
    '\u823B',
    '\u8270',
    '\u8273',
    '\u827A',
    '\u8282',
    '\u8288',
    '\u8297',
    '\u829C',
    '\u82A6',
    '\u82B8',
    '\u82C1',
    '\u82C7',
    '\u82C8',
    '\u82CB',
    '\u82CC',
    '\u82CD',
    '\u82CE',
    '\u82CF',
    '\u82E7',
    '\u82F9',
    '\u8303',
    '\u830E',
    '\u830F',
    '\u8311',
    '\u8314',
    '\u8315',
    '\u8327',
    '\u8346',
    '\u8350',
    '\u8359',
    '\u835A',
    '\u835B',
    '\u835C',
    '\u835D',
    '\u835E',
    '\u835F',
    '\u8360',
    '\u8361',
    '\u8363',
    '\u8364',
    '\u8365',
    '\u8366',
    '\u8367',
    '\u8368',
    '\u8369',
    '\u836A',
    '\u836B',
    '\u836C',
    '\u836D',
    '\u836E',
    '\u836F',
    '\u8385',
    '\u83B1',
    '\u83B2',
    '\u83B3',
    '\u83B4',
    '\u83B6',
    '\u83B7',
    '\u83B8',
    '\u83B9',
    '\u83BA',
    '\u83BC',
    '\u841D',
    '\u8424',
    '\u8425',
    '\u8426',
    '\u8427',
    '\u8428',
    '\u8471',
    '\u8487',
    '\u8489',
    '\u848B',
    '\u848C',
    '\u84DD',
    '\u84DF',
    '\u84E0',
    '\u84E3',
    '\u84E5',
    '\u84E6',
    '\u8502',
    '\u8537',
    '\u8539',
    '\u853A',
    '\u853C',
    '\u8570',
    '\u8572',
    '\u8574',
    '\u85AE',
    '\u85D3',
    '\u8616',
    '\u864F',
    '\u8651',
    '\u865A',
    '\u866B',
    '\u866C',
    '\u866E',
    '\u867D',
    '\u867E',
    '\u867F',
    '\u8680',
    '\u8681',
    '\u8682',
    '\u8683',
    '\u8695',
    '\u86AC',
    '\u86CA',
    '\u86CE',
    '\u86CF',
    '\u86EE',
    '\u86F0',
    '\u86F1',
    '\u86F2',
    '\u86F3',
    '\u86F4',
    '\u8715',
    '\u8717',
    '\u8721',
    '\u8747',
    '\u8748',
    '\u8749',
    '\u877C',
    '\u877E',
    '\u8780',
    '\u87A8',
    '\u87CF',
    '\u8845',
    '\u8854',
    '\u8865',
    '\u8868',
    '\u886C',
    '\u886E',
    '\u8884',
    '\u8885',
    '\u8886',
    '\u889C',
    '\u88AD',
    '\u88AF',
    '\u88C5',
    '\u88C6',
    '\u88C8',
    '\u88E2',
    '\u88E3',
    '\u88E4',
    '\u88E5',
    '\u891B',
    '\u8934',
    '\u8955',
    '\u89C1',
    '\u89C2',
    '\u89C3',
    '\u89C4',
    '\u89C5',
    '\u89C6',
    '\u89C7',
    '\u89C8',
    '\u89C9',
    '\u89CA',
    '\u89CB',
    '\u89CC',
    '\u89CD',
    '\u89CE',
    '\u89CF',
    '\u89D0',
    '\u89D1',
    '\u89DE',
    '\u89E6',
    '\u89EF',
    '\u8A1A',
    '\u8A5F',
    '\u8A89',
    '\u8A8A',
    '\u8BA0',
    '\u8BA1',
    '\u8BA2',
    '\u8BA3',
    '\u8BA4',
    '\u8BA5',
    '\u8BA6',
    '\u8BA7',
    '\u8BA8',
    '\u8BA9',
    '\u8BAA',
    '\u8BAB',
    '\u8BAC',
    '\u8BAD',
    '\u8BAE',
    '\u8BAF',
    '\u8BB0',
    '\u8BB1',
    '\u8BB2',
    '\u8BB3',
    '\u8BB4',
    '\u8BB5',
    '\u8BB6',
    '\u8BB7',
    '\u8BB8',
    '\u8BB9',
    '\u8BBA',
    '\u8BBB',
    '\u8BBC',
    '\u8BBD',
    '\u8BBE',
    '\u8BBF',
    '\u8BC0',
    '\u8BC1',
    '\u8BC2',
    '\u8BC3',
    '\u8BC4',
    '\u8BC5',
    '\u8BC6',
    '\u8BC7',
    '\u8BC8',
    '\u8BC9',
    '\u8BCA',
    '\u8BCB',
    '\u8BCC',
    '\u8BCD',
    '\u8BCE',
    '\u8BCF',
    '\u8BD0',
    '\u8BD1',
    '\u8BD2',
    '\u8BD3',
    '\u8BD4',
    '\u8BD5',
    '\u8BD6',
    '\u8BD7',
    '\u8BD8',
    '\u8BD9',
    '\u8BDA',
    '\u8BDB',
    '\u8BDC',
    '\u8BDD',
    '\u8BDE',
    '\u8BDF',
    '\u8BE0',
    '\u8BE1',
    '\u8BE2',
    '\u8BE3',
    '\u8BE4',
    '\u8BE5',
    '\u8BE6',
    '\u8BE7',
    '\u8BE8',
    '\u8BE9',
    '\u8BEA',
    '\u8BEB',
    '\u8BEC',
    '\u8BED',
    '\u8BEE',
    '\u8BEF',
    '\u8BF0',
    '\u8BF1',
    '\u8BF2',
    '\u8BF3',
    '\u8BF4',
    '\u8BF5',
    '\u8BF6',
    '\u8BF7',
    '\u8BF8',
    '\u8BF9',
    '\u8BFA',
    '\u8BFB',
    '\u8BFC',
    '\u8BFD',
    '\u8BFE',
    '\u8BFF',
    '\u8C00',
    '\u8C01',
    '\u8C02',
    '\u8C03',
    '\u8C04',
    '\u8C05',
    '\u8C06',
    '\u8C07',
    '\u8C08',
    '\u8C0A',
    '\u8C0B',
    '\u8C0C',
    '\u8C0D',
    '\u8C0E',
    '\u8C0F',
    '\u8C10',
    '\u8C11',
    '\u8C12',
    '\u8C13',
    '\u8C14',
    '\u8C15',
    '\u8C16',
    '\u8C17',
    '\u8C18',
    '\u8C19',
    '\u8C1A',
    '\u8C1B',
    '\u8C1C',
    '\u8C1D',
    '\u8C1E',
    '\u8C1F',
    '\u8C20',
    '\u8C21',
    '\u8C22',
    '\u8C23',
    '\u8C24',
    '\u8C25',
    '\u8C26',
    '\u8C27',
    '\u8C28',
    '\u8C29',
    '\u8C2A',
    '\u8C2B',
    '\u8C2C',
    '\u8C2D',
    '\u8C2E',
    '\u8C2F',
    '\u8C30',
    '\u8C31',
    '\u8C32',
    '\u8C33',
    '\u8C34',
    '\u8C35',
    '\u8C36',
    '\u8C37',
    '\u8C6E',
    '\u8D1D',
    '\u8D1E',
    '\u8D1F',
    '\u8D20',
    '\u8D21',
    '\u8D22',
    '\u8D23',
    '\u8D24',
    '\u8D25',
    '\u8D26',
    '\u8D27',
    '\u8D28',
    '\u8D29',
    '\u8D2A',
    '\u8D2B',
    '\u8D2C',
    '\u8D2D',
    '\u8D2E',
    '\u8D2F',
    '\u8D30',
    '\u8D31',
    '\u8D32',
    '\u8D33',
    '\u8D34',
    '\u8D35',
    '\u8D36',
    '\u8D37',
    '\u8D38',
    '\u8D39',
    '\u8D3A',
    '\u8D3B',
    '\u8D3C',
    '\u8D3D',
    '\u8D3E',
    '\u8D3F',
    '\u8D40',
    '\u8D41',
    '\u8D42',
    '\u8D43',
    '\u8D44',
    '\u8D45',
    '\u8D46',
    '\u8D47',
    '\u8D48',
    '\u8D49',
    '\u8D4A',
    '\u8D4B',
    '\u8D4C',
    '\u8D4D',
    '\u8D4E',
    '\u8D4F',
    '\u8D50',
    '\u8D51',
    '\u8D52',
    '\u8D53',
    '\u8D54',
    '\u8D55',
    '\u8D56',
    '\u8D57',
    '\u8D58',
    '\u8D59',
    '\u8D5A',
    '\u8D5B',
    '\u8D5C',
    '\u8D5D',
    '\u8D5E',
    '\u8D5F',
    '\u8D60',
    '\u8D61',
    '\u8D62',
    '\u8D63',
    '\u8D6A',
    '\u8D75',
    '\u8D76',
    '\u8D8B',
    '\u8DB1',
    '\u8DB8',
    '\u8DC3',
    '\u8DC4',
    '\u8DDE',
    '\u8DF5',
    '\u8DF6',
    '\u8DF7',
    '\u8DF8',
    '\u8DF9',
    '\u8DFB',
    '\u8E0A',
    '\u8E0C',
    '\u8E2A',
    '\u8E2C',
    '\u8E2F',
    '\u8E51',
    '\u8E52',
    '\u8E70',
    '\u8E7F',
    '\u8E8F',
    '\u8E9C',
    '\u8EAF',
    '\u8F66',
    '\u8F67',
    '\u8F68',
    '\u8F69',
    '\u8F6A',
    '\u8F6B',
    '\u8F6C',
    '\u8F6D',
    '\u8F6E',
    '\u8F6F',
    '\u8F70',
    '\u8F71',
    '\u8F72',
    '\u8F73',
    '\u8F74',
    '\u8F75',
    '\u8F76',
    '\u8F77',
    '\u8F78',
    '\u8F79',
    '\u8F7A',
    '\u8F7B',
    '\u8F7C',
    '\u8F7D',
    '\u8F7E',
    '\u8F7F',
    '\u8F80',
    '\u8F81',
    '\u8F82',
    '\u8F83',
    '\u8F84',
    '\u8F85',
    '\u8F86',
    '\u8F87',
    '\u8F88',
    '\u8F89',
    '\u8F8A',
    '\u8F8B',
    '\u8F8C',
    '\u8F8D',
    '\u8F8E',
    '\u8F8F',
    '\u8F90',
    '\u8F91',
    '\u8F92',
    '\u8F93',
    '\u8F94',
    '\u8F95',
    '\u8F96',
    '\u8F97',
    '\u8F98',
    '\u8F99',
    '\u8F9A',
    '\u8F9E',
    '\u8FA9',
    '\u8FAB',
    '\u8FB9',
    '\u8FBD',
    '\u8FBE',
    '\u8FC1',
    '\u8FC7',
    '\u8FC8',
    '\u8FD0',
    '\u8FD8',
    '\u8FD9',
    '\u8FDB',
    '\u8FDC',
    '\u8FDD',
    '\u8FDE',
    '\u8FDF',
    '\u8FE9',
    '\u8FF3',
    '\u8FF9',
    '\u9002',
    '\u9009',
    '\u900A',
    '\u9012',
    '\u9026',
    '\u903B',
    '\u9057',
    '\u9065',
    '\u9093',
    '\u909D',
    '\u90AC',
    '\u90AE',
    '\u90B9',
    '\u90BA',
    '\u90BB',
    '\u90C1',
    '\u90CF',
    '\u90D0',
    '\u90D1',
    '\u90D3',
    '\u90E6',
    '\u90E7',
    '\u90F8',
    '\u9142',
    '\u915D',
    '\u9166',
    '\u9171',
    '\u917D',
    '\u917E',
    '\u917F',
    '\u91C7',
    '\u91CA',
    '\u91CC',
    '\u9274',
    '\u92AE',
    '\u933E',
    '\u9485',
    '\u9486',
    '\u9487',
    '\u9488',
    '\u9489',
    '\u948A',
    '\u948B',
    '\u948C',
    '\u948D',
    '\u948E',
    '\u948F',
    '\u9490',
    '\u9491',
    '\u9492',
    '\u9493',
    '\u9494',
    '\u9495',
    '\u9496',
    '\u9497',
    '\u9498',
    '\u9499',
    '\u949A',
    '\u949B',
    '\u949C',
    '\u949D',
    '\u949E',
    '\u949F',
    '\u94A0',
    '\u94A1',
    '\u94A2',
    '\u94A3',
    '\u94A4',
    '\u94A5',
    '\u94A6',
    '\u94A7',
    '\u94A8',
    '\u94A9',
    '\u94AA',
    '\u94AB',
    '\u94AC',
    '\u94AD',
    '\u94AE',
    '\u94AF',
    '\u94B0',
    '\u94B1',
    '\u94B2',
    '\u94B3',
    '\u94B4',
    '\u94B5',
    '\u94B6',
    '\u94B7',
    '\u94B8',
    '\u94B9',
    '\u94BA',
    '\u94BB',
    '\u94BC',
    '\u94BD',
    '\u94BE',
    '\u94BF',
    '\u94C0',
    '\u94C1',
    '\u94C2',
    '\u94C3',
    '\u94C4',
    '\u94C5',
    '\u94C6',
    '\u94C7',
    '\u94C8',
    '\u94C9',
    '\u94CA',
    '\u94CB',
    '\u94CC',
    '\u94CD',
    '\u94CE',
    '\u94CF',
    '\u94D0',
    '\u94D1',
    '\u94D2',
    '\u94D3',
    '\u94D4',
    '\u94D5',
    '\u94D6',
    '\u94D7',
    '\u94D8',
    '\u94D9',
    '\u94DA',
    '\u94DB',
    '\u94DC',
    '\u94DD',
    '\u94DE',
    '\u94DF',
    '\u94E0',
    '\u94E1',
    '\u94E2',
    '\u94E3',
    '\u94E4',
    '\u94E5',
    '\u94E6',
    '\u94E7',
    '\u94E8',
    '\u94E9',
    '\u94EA',
    '\u94EB',
    '\u94EC',
    '\u94ED',
    '\u94EE',
    '\u94EF',
    '\u94F0',
    '\u94F1',
    '\u94F2',
    '\u94F3',
    '\u94F4',
    '\u94F5',
    '\u94F6',
    '\u94F7',
    '\u94F8',
    '\u94F9',
    '\u94FA',
    '\u94FB',
    '\u94FC',
    '\u94FD',
    '\u94FE',
    '\u94FF',
    '\u9500',
    '\u9501',
    '\u9502',
    '\u9503',
    '\u9504',
    '\u9505',
    '\u9506',
    '\u9507',
    '\u9508',
    '\u9509',
    '\u950A',
    '\u950B',
    '\u950C',
    '\u950D',
    '\u950E',
    '\u950F',
    '\u9510',
    '\u9511',
    '\u9512',
    '\u9513',
    '\u9514',
    '\u9515',
    '\u9516',
    '\u9517',
    '\u9518',
    '\u9519',
    '\u951A',
    '\u951B',
    '\u951C',
    '\u951D',
    '\u951E',
    '\u951F',
    '\u9520',
    '\u9521',
    '\u9522',
    '\u9523',
    '\u9524',
    '\u9525',
    '\u9526',
    '\u9527',
    '\u9528',
    '\u9529',
    '\u952A',
    '\u952B',
    '\u952C',
    '\u952D',
    '\u952E',
    '\u952F',
    '\u9530',
    '\u9531',
    '\u9532',
    '\u9533',
    '\u9534',
    '\u9535',
    '\u9536',
    '\u9537',
    '\u9538',
    '\u9539',
    '\u953A',
    '\u953B',
    '\u953C',
    '\u953D',
    '\u953E',
    '\u953F',
    '\u9540',
    '\u9541',
    '\u9542',
    '\u9543',
    '\u9544',
    '\u9545',
    '\u9546',
    '\u9547',
    '\u9548',
    '\u9549',
    '\u954A',
    '\u954B',
    '\u954C',
    '\u954D',
    '\u954E',
    '\u954F',
    '\u9550',
    '\u9551',
    '\u9552',
    '\u9553',
    '\u9554',
    '\u9555',
    '\u9556',
    '\u9557',
    '\u9558',
    '\u9559',
    '\u955A',
    '\u955B',
    '\u955C',
    '\u955D',
    '\u955E',
    '\u955F',
    '\u9560',
    '\u9561',
    '\u9562',
    '\u9563',
    '\u9564',
    '\u9565',
    '\u9566',
    '\u9567',
    '\u9568',
    '\u9569',
    '\u956A',
    '\u956B',
    '\u956C',
    '\u956D',
    '\u956E',
    '\u956F',
    '\u9570',
    '\u9571',
    '\u9572',
    '\u9573',
    '\u9574',
    '\u9575',
    '\u9576',
    '\u957F',
    '\u95E8',
    '\u95E9',
    '\u95EA',
    '\u95EB',
    '\u95EC',
    '\u95ED',
    '\u95EE',
    '\u95EF',
    '\u95F0',
    '\u95F1',
    '\u95F2',
    '\u95F3',
    '\u95F4',
    '\u95F5',
    '\u95F6',
    '\u95F7',
    '\u95F8',
    '\u95F9',
    '\u95FA',
    '\u95FB',
    '\u95FC',
    '\u95FD',
    '\u95FE',
    '\u95FF',
    '\u9600',
    '\u9601',
    '\u9602',
    '\u9603',
    '\u9604',
    '\u9605',
    '\u9606',
    '\u9607',
    '\u9608',
    '\u9609',
    '\u960A',
    '\u960B',
    '\u960C',
    '\u960D',
    '\u960E',
    '\u960F',
    '\u9610',
    '\u9611',
    '\u9612',
    '\u9613',
    '\u9614',
    '\u9615',
    '\u9616',
    '\u9617',
    '\u9618',
    '\u9619',
    '\u961A',
    '\u961B',
    '\u961F',
    '\u9633',
    '\u9634',
    '\u9635',
    '\u9636',
    '\u9645',
    '\u9646',
    '\u9647',
    '\u9648',
    '\u9649',
    '\u9655',
    '\u9667',
    '\u9668',
    '\u9669',
    '\u968F',
    '\u9690',
    '\u96B6',
    '\u96BD',
    '\u96BE',
    '\u96CF',
    '\u96E0',
    '\u96F3',
    '\u96FE',
    '\u9701',
    '\u9721',
    '\u972D',
    '\u9753',
    '\u9759',
    '\u9762',
    '\u9765',
    '\u9791',
    '\u9792',
    '\u97AF',
    '\u97E6',
    '\u97E7',
    '\u97E8',
    '\u97E9',
    '\u97EA',
    '\u97EB',
    '\u97EC',
    '\u97F5',
    '\u9875',
    '\u9876',
    '\u9877',
    '\u9878',
    '\u9879',
    '\u987A',
    '\u987B',
    '\u987C',
    '\u987D',
    '\u987E',
    '\u987F',
    '\u9880',
    '\u9881',
    '\u9882',
    '\u9883',
    '\u9884',
    '\u9885',
    '\u9886',
    '\u9887',
    '\u9888',
    '\u9889',
    '\u988A',
    '\u988B',
    '\u988C',
    '\u988D',
    '\u988E',
    '\u988F',
    '\u9890',
    '\u9891',
    '\u9892',
    '\u9893',
    '\u9894',
    '\u9895',
    '\u9896',
    '\u9897',
    '\u9898',
    '\u9899',
    '\u989A',
    '\u989B',
    '\u989C',
    '\u989D',
    '\u989E',
    '\u989F',
    '\u98A0',
    '\u98A1',
    '\u98A2',
    '\u98A3',
    '\u98A4',
    '\u98A5',
    '\u98A6',
    '\u98A7',
    '\u98CE',
    '\u98CF',
    '\u98D0',
    '\u98D1',
    '\u98D2',
    '\u98D3',
    '\u98D4',
    '\u98D5',
    '\u98D6',
    '\u98D7',
    '\u98D8',
    '\u98D9',
    '\u98DA',
    '\u98DE',
    '\u98E8',
    '\u990D',
    '\u9963',
    '\u9964',
    '\u9965',
    '\u9966',
    '\u9967',
    '\u9968',
    '\u9969',
    '\u996A',
    '\u996B',
    '\u996C',
    '\u996D',
    '\u996E',
    '\u996F',
    '\u9970',
    '\u9971',
    '\u9972',
    '\u9973',
    '\u9974',
    '\u9975',
    '\u9976',
    '\u9977',
    '\u9978',
    '\u9979',
    '\u997A',
    '\u997B',
    '\u997C',
    '\u997D',
    '\u997E',
    '\u997F',
    '\u9980',
    '\u9981',
    '\u9982',
    '\u9983',
    '\u9984',
    '\u9985',
    '\u9986',
    '\u9987',
    '\u9988',
    '\u9989',
    '\u998A',
    '\u998B',
    '\u998C',
    '\u998D',
    '\u998E',
    '\u998F',
    '\u9990',
    '\u9991',
    '\u9992',
    '\u9993',
    '\u9994',
    '\u9995',
    '\u9A6C',
    '\u9A6D',
    '\u9A6E',
    '\u9A6F',
    '\u9A70',
    '\u9A71',
    '\u9A72',
    '\u9A73',
    '\u9A74',
    '\u9A75',
    '\u9A76',
    '\u9A77',
    '\u9A78',
    '\u9A79',
    '\u9A7A',
    '\u9A7B',
    '\u9A7C',
    '\u9A7D',
    '\u9A7E',
    '\u9A7F',
    '\u9A80',
    '\u9A81',
    '\u9A82',
    '\u9A83',
    '\u9A84',
    '\u9A85',
    '\u9A86',
    '\u9A87',
    '\u9A88',
    '\u9A89',
    '\u9A8A',
    '\u9A8B',
    '\u9A8C',
    '\u9A8D',
    '\u9A8E',
    '\u9A8F',
    '\u9A90',
    '\u9A91',
    '\u9A92',
    '\u9A93',
    '\u9A94',
    '\u9A95',
    '\u9A96',
    '\u9A97',
    '\u9A98',
    '\u9A99',
    '\u9A9A',
    '\u9A9B',
    '\u9A9C',
    '\u9A9D',
    '\u9A9E',
    '\u9A9F',
    '\u9AA0',
    '\u9AA1',
    '\u9AA2',
    '\u9AA3',
    '\u9AA4',
    '\u9AA5',
    '\u9AA6',
    '\u9AA7',
    '\u9AC5',
    '\u9ACB',
    '\u9ACC',
    '\u9B13',
    '\u9B47',
    '\u9B49',
    '\u9C7C',
    '\u9C7D',
    '\u9C7E',
    '\u9C7F',
    '\u9C80',
    '\u9C81',
    '\u9C82',
    '\u9C83',
    '\u9C84',
    '\u9C85',
    '\u9C86',
    '\u9C88',
    '\u9C89',
    '\u9C8A',
    '\u9C8B',
    '\u9C8C',
    '\u9C8D',
    '\u9C8E',
    '\u9C8F',
    '\u9C90',
    '\u9C91',
    '\u9C92',
    '\u9C93',
    '\u9C94',
    '\u9C95',
    '\u9C96',
    '\u9C97',
    '\u9C98',
    '\u9C99',
    '\u9C9A',
    '\u9C9B',
    '\u9C9C',
    '\u9C9D',
    '\u9C9E',
    '\u9C9F',
    '\u9CA0',
    '\u9CA1',
    '\u9CA2',
    '\u9CA3',
    '\u9CA4',
    '\u9CA5',
    '\u9CA6',
    '\u9CA7',
    '\u9CA8',
    '\u9CA9',
    '\u9CAA',
    '\u9CAB',
    '\u9CAC',
    '\u9CAD',
    '\u9CAE',
    '\u9CAF',
    '\u9CB0',
    '\u9CB1',
    '\u9CB2',
    '\u9CB3',
    '\u9CB4',
    '\u9CB5',
    '\u9CB7',
    '\u9CB8',
    '\u9CB9',
    '\u9CBA',
    '\u9CBB',
    '\u9CBC',
    '\u9CBD',
    '\u9CBE',
    '\u9CBF',
    '\u9CC0',
    '\u9CC1',
    '\u9CC2',
    '\u9CC3',
    '\u9CC4',
    '\u9CC5',
    '\u9CC6',
    '\u9CC7',
    '\u9CC8',
    '\u9CC9',
    '\u9CCA',
    '\u9CCB',
    '\u9CCC',
    '\u9CCD',
    '\u9CCE',
    '\u9CCF',
    '\u9CD0',
    '\u9CD1',
    '\u9CD2',
    '\u9CD3',
    '\u9CD4',
    '\u9CD5',
    '\u9CD6',
    '\u9CD7',
    '\u9CD8',
    '\u9CD9',
    '\u9CDA',
    '\u9CDB',
    '\u9CDC',
    '\u9CDD',
    '\u9CDE',
    '\u9CDF',
    '\u9CE0',
    '\u9CE1',
    '\u9CE2',
    '\u9CE3',
    '\u9E1F',
    '\u9E20',
    '\u9E21',
    '\u9E22',
    '\u9E23',
    '\u9E24',
    '\u9E25',
    '\u9E26',
    '\u9E27',
    '\u9E28',
    '\u9E29',
    '\u9E2A',
    '\u9E2B',
    '\u9E2C',
    '\u9E2D',
    '\u9E2E',
    '\u9E2F',
    '\u9E30',
    '\u9E31',
    '\u9E32',
    '\u9E33',
    '\u9E34',
    '\u9E35',
    '\u9E36',
    '\u9E37',
    '\u9E38',
    '\u9E39',
    '\u9E3A',
    '\u9E3B',
    '\u9E3C',
    '\u9E3D',
    '\u9E3E',
    '\u9E3F',
    '\u9E40',
    '\u9E41',
    '\u9E42',
    '\u9E43',
    '\u9E44',
    '\u9E45',
    '\u9E46',
    '\u9E47',
    '\u9E48',
    '\u9E49',
    '\u9E4A',
    '\u9E4B',
    '\u9E4C',
    '\u9E4D',
    '\u9E4E',
    '\u9E4F',
    '\u9E50',
    '\u9E51',
    '\u9E52',
    '\u9E53',
    '\u9E54',
    '\u9E55',
    '\u9E56',
    '\u9E57',
    '\u9E58',
    '\u9E59',
    '\u9E5A',
    '\u9E5B',
    '\u9E5C',
    '\u9E5D',
    '\u9E5E',
    '\u9E5F',
    '\u9E60',
    '\u9E61',
    '\u9E62',
    '\u9E63',
    '\u9E64',
    '\u9E65',
    '\u9E66',
    '\u9E67',
    '\u9E68',
    '\u9E69',
    '\u9E6A',
    '\u9E6B',
    '\u9E6C',
    '\u9E6D',
    '\u9E6E',
    '\u9E6F',
    '\u9E70',
    '\u9E71',
    '\u9E72',
    '\u9E73',
    '\u9E74',
    '\u9E7E',
    '\u9EA6',
    '\u9EB8',
    '\u9EC4',
    '\u9EC9',
    '\u9EE1',
    '\u9EE9',
    '\u9EEA',
    '\u9EFE',
    '\u9F0B',
    '\u9F0D',
    '\u9F17',
    '\u9F39',
    '\u9F50',
    '\u9F51',
    '\u9F7F',
    '\u9F80',
    '\u9F81',
    '\u9F82',
    '\u9F83',
    '\u9F84',
    '\u9F85',
    '\u9F86',
    '\u9F87',
    '\u9F88',
    '\u9F89',
    '\u9F8A',
    '\u9F8B',
    '\u9F8C',
    '\u9F99',
    '\u9F9A',
    '\u9F9B',
    '\u9F9F' ]
  end
end
